<?php

$LANG = array(
    'organization' => '組織',
    'name' => '姓名',
    'website' => '網站',
    'work_phone' => '電話',
    'address' => '地址',
    'address1' => '街道',
    'address2' => '大樓/套房',
    'city' => '城市',
    'state' => '州/省',
    'postal_code' => '郵遞區號',
    'country_id' => '國家',
    'contacts' => '聯絡人',
    'first_name' => '名字',
    'last_name' => '姓氏',
    'phone' => '電話',
    'email' => '電子郵件',
    'additional_info' => '更多資訊',
    'payment_terms' => '付款條件',
    'currency_id' => '貨幣',
    'size_id' => '公司規模',
    'industry_id' => '工業',
    'private_notes' => '私人註記',
    'invoice' => '發票',
    'client' => '用戶',
    'invoice_date' => '發票開立日期',
    'due_date' => '應付款日期',
    'invoice_number' => '發票號碼',
    'invoice_number_short' => '發票 #',
    'po_number' => '郵遞區號',
    'po_number_short' => '郵遞區號 #',
    'frequency_id' => '頻率',
    'discount' => '折扣',
    'taxes' => '各類稅金',
    'tax' => '稅',
    'item' => '品項',
    'description' => '描述',
    'unit_cost' => '單位成本',
    'quantity' => '數量',
    'line_total' => '總計',
    'subtotal' => '小計',
    'paid_to_date' => '已付',
    'balance_due' => '到期餘額',
    'invoice_design_id' => '設計',
    'terms' => '條款',
    'your_invoice' => '您的發票',
    'remove_contact' => '移除聯絡資料',
    'add_contact' => '新增聯絡資料',
    'create_new_client' => '新增用戶',
    'edit_client_details' => '編輯用戶詳細資料',
    'enable' => '啟用',
    'learn_more' => '瞭解更多',
    'manage_rates' => '管理率',
    'note_to_client' => '給用戶的註記',
    'invoice_terms' => '發票之條款',
    'save_as_default_terms' => '儲存為預設品項',
    'download_pdf' => '下載 PDF',
    'pay_now' => '立即付款',
    'save_invoice' => '儲存發票',
    'clone_invoice' => '再製至發票',
    'archive_invoice' => '歸檔發票資料',
    'delete_invoice' => '刪除發票',
    'email_invoice' => '以電子郵件寄送發票',
    'enter_payment' => '輸入付款資料',
    'tax_rates' => '稅率',
    'rate' => '率',
    'settings' => '設定',
    'enable_invoice_tax' => '啟用註明<b>印花稅</b>',
    'enable_line_item_tax' => '啟用註明<b>各品項稅額</b>',
    'dashboard' => '儀表板',
    'dashboard_totals_in_all_currencies_help' => '注意: 加入名為「:name」的 :link，以使用單一基礎貨幣顯示總計。',
    'clients' => '用戶',
    'invoices' => '發票',
    'payments' => '付款',
    'credits' => '貸款',
    'history' => '歷程紀錄',
    'search' => '搜尋',
    'sign_up' => '登入',
    'guest' => '訪客',
    'company_details' => '公司之詳細資料',
    'online_payments' => '線上付款',
    'notifications' => '注意事項',
    'import_export' => '匯入 | 匯出',
    'done' => '完成',
    'save' => '儲存',
    'create' => '建立',
    'upload' => '上傳',
    'import' => '匯入',
    'download' => '下載',
    'cancel' => '取消',
    'close' => '關閉',
    'provide_email' => '請提供有效的電子郵件地址',
    'powered_by' => '技術提供',
    'no_items' => '無品項',
    'recurring_invoices' => '週期性發票',
    'recurring_help' => '<p>每週、每兩個月、每月、每季度或每年自動向客戶發送相同的發票。</p>
        <p>使用 :MONTH, :QUARTER 或 :YEAR 作為動態日期。 基本數學也很管用, 例如: :MONTH-1。</p>
        <p>動態發票變數範例:</p>
        <ul>
          <li>":MONTH" 月份的 Gym 會員 >> "7 月份的 Gym 會員"</li>
          <li>":YEAR+1 年度訂閱" >> "2015 年度訂閱"</li>
          <li>":QUARTER+1 的保留人付款" >> "Q2 的保留人付款"</li>
        </ul>',
    'recurring_quotes' => '週期性報價單',
    'in_total_revenue' => '總收入',
    'billed_client' => '帳單用戶',
    'billed_clients' => '帳單用戶',
    'active_client' => '使用中用戶',
    'active_clients' => '使用中用戶',
    'invoices_past_due' => '發票過去到期',
    'upcoming_invoices' => '即將到期的發票',
    'average_invoice' => '平均銷售額',
    'archive' => '歸檔',
    'delete' => '刪除',
    'archive_client' => '歸檔用戶',
    'delete_client' => '刪除用戶',
    'archive_payment' => '歸檔付款資料',
    'delete_payment' => '刪除付款紀錄',
    'archive_credit' => '歸檔貸款資料',
    'delete_credit' => '刪除貸款資料',
    'show_archived_deleted' => '顯示歸檔的／刪除的資料',
    'filter' => '篩選器',
    'new_client' => '新用戶',
    'new_invoice' => '新發票',
    'new_payment' => '輸入付款資料',
    'new_credit' => '輸入貸款資料',
    'contact' => '聯絡人',
    'date_created' => '建立日期',
    'last_login' => '上次登入',
    'balance' => '差額',
    'action' => '動作',
    'status' => '狀態',
    'invoice_total' => '發票總額',
    'frequency' => '頻率',
    'range' => 'Range',
    'start_date' => '開始日期',
    'end_date' => '結束日期',
    'transaction_reference' => '轉帳資料',
    'method' => '方式',
    'payment_amount' => '付款金額',
    'payment_date' => '付款日期',
    'credit_amount' => '貸款金額',
    'credit_balance' => '貸款餘額',
    'credit_date' => '貸款日期',
    'empty_table' => '資料表中無此資料',
    'select' => '選擇',
    'edit_client' => '編輯用戶',
    'edit_invoice' => '編輯發票',
    'create_invoice' => '建立發票',
    'enter_credit' => '輸入貸款資料',
    'last_logged_in' => '上次登入於',
    'details' => '詳細資料',
    'standing' => '資格',
    'credit' => '貸款',
    'activity' => '活動',
    'date' => '日期',
    'message' => '訊息',
    'adjustment' => '調整',
    'are_you_sure' => '您確定嗎?',
    'payment_type_id' => '付款方式',
    'amount' => '金額',
    'work_email' => '電子郵件',
    'language_id' => '語言',
    'timezone_id' => '時區',
    'date_format_id' => '日期格式',
    'datetime_format_id' => '日期/時間格式',
    'users' => '使用者',
    'localization' => '本地化',
    'remove_logo' => '移除標誌',
    'logo_help' => '支援格式: JPEG, GIF 和 PNG',
    'payment_gateway' => '付款閘道',
    'gateway_id' => '閘道',
    'email_notifications' => '以電子郵件通知',
    'email_sent' => '當發票<b>寄出</b>後，以電子郵件通知我',
    'email_viewed' => '當發票<b>已檢視</b>後，以電子郵件通知我',
    'email_paid' => '當發票款項<b>已付清</b>後，以電子郵件通知我',
    'site_updates' => '網站更新',
    'custom_messages' => '自訂訊息',
    'default_email_footer' => '設定預設<b>電子郵件簽署</b>',
    'select_file' => '請選擇一個檔案',
    'first_row_headers' => '使用第一列作為標題列',
    'column' => '欄',
    'sample' => '樣本',
    'import_to' => '匯入至',
    'client_will_create' => '將建立用戶',
    'clients_will_create' => '將建立用戶',
    'email_settings' => '電子郵件設定',
    'client_view_styling' => '用戶檢視樣式',
    'pdf_email_attachment' => '附加 PDF 檔案',
    'custom_css' => '自訂樣式表',
    'import_clients' => '匯入用戶資料',
    'csv_file' => 'CSV 檔案',
    'export_clients' => '匯出用戶資料',
    'created_client' => '建立用戶資料成功',
    'created_clients' => '建立 :count 筆客戶資料成功',
    'updated_settings' => '更新設定成功',
    'removed_logo' => '移除標誌成功',
    'sent_message' => '寄出訊息成功',
    'invoice_error' => '請確認選取一個用戶並更正任何錯誤',
    'limit_clients' => '抱歉，這將超過 :count 個用戶的限制',
    'payment_error' => '您的付款處理過程有誤。請稍後重試。',
    'registration_required' => '請登入以使用電子郵件傳送發票',
    'confirmation_required' => '請確認您的電子郵件地址 :link ，以重寄確認函。',
    'updated_client' => '更新用戶資料成功',
    'archived_client' => '歸檔用戶資料成功',
    'archived_clients' => '歸檔 :count 個用戶資料成功',
    'deleted_client' => '刪除用戶資料成功',
    'deleted_clients' => '刪除 :count 筆用戶資料成功',
    'updated_invoice' => '更新發票成功',
    'created_invoice' => '製作完成的發票',
    'cloned_invoice' => '完成複製的發票',
    'emailed_invoice' => '以電子郵件寄出發票成功',
    'and_created_client' => '並建立用戶資料',
    'archived_invoice' => '歸檔發票資料成功',
    'archived_invoices' => '歸檔 :count 筆發票資料成功',
    'deleted_invoice' => '刪除發票成功',
    'deleted_invoices' => '刪除 :count 筆發票成功',
    'created_payment' => '已建立完成的付款資料',
    'created_payments' => '建立 :count 筆付款成功',
    'archived_payment' => '歸檔付款資料成功',
    'archived_payments' => '歸檔 :count 筆付款資料成功',
    'deleted_payment' => '刪除付款資料成功',
    'deleted_payments' => '刪除 :count 筆付款資料成功',
    'applied_payment' => '完成套用的付款資料',
    'created_credit' => '建立貸款資料完成',
    'archived_credit' => '歸檔貸款資料成功',
    'archived_credits' => '歸檔 :count 筆貸款資料成功',
    'deleted_credit' => '刪除貸款資料成功',
    'deleted_credits' => '刪除 :count 筆貸款資料成功',
    'imported_file' => '匯入檔案成功',
    'updated_vendor' => '更新供應商資料成功',
    'created_vendor' => '建立供應商資料成功',
    'archived_vendor' => '歸檔供應商資料成功',
    'archived_vendors' => '歸檔 :count 筆供應商資料成功',
    'deleted_vendor' => '刪除供應商成功',
    'deleted_vendors' => '刪除 :count 筆供應商成功',
    'confirmation_subject' => '確認在 Invoice Ninja 的帳號',
    'confirmation_header' => '確認帳號',
    'confirmation_message' => '請存取以下連結來確認您的帳號。',
    'invoice_subject' => ':account 帳戶下的第 :number 筆新發票',
    'invoice_message' => '若要檢視您的 :amount 之發票，按一下以下連結。',
    'payment_subject' => '收到的付款',
    'payment_message' => '感謝您支付 :amount 元。',
    'email_salutation' => ':name 您好，',
    'email_signature' => '向您致意，',
    'email_from' => 'Invoice Ninja 團隊',
    'invoice_link_message' => '若要檢視此發票，按一下以下連結:',
    'notification_invoice_paid_subject' => '發票 :invoice 已由 :client付款',
    'notification_invoice_sent_subject' => '發票 :invoice 已寄送給 :client',
    'notification_invoice_viewed_subject' => ':client已閱覽了發票 :invoice',
    'notification_invoice_paid' => '用戶 :client 對發票 :invoice 支付 :amount 的金額。',
    'notification_invoice_sent' => '以下用戶 :client 透過電子郵件傳送 :amount 的發票 :invoice。',
    'notification_invoice_viewed' => '以下用戶 :client 檢視 :amount 的發票 :invoice。',
    'reset_password' => '您可重新點選以下按鈕來重新設定您的帳戶密碼:',
    'secure_payment' => '安全付款',
    'card_number' => '卡號',
    'expiration_month' => '效期月份',
    'expiration_year' => '效期年份',
    'cvv' => '信用卡認證編號',
    'logout' => '登出',
    'sign_up_to_save' => '登入，以便儲存您的工作',
    'agree_to_terms' => '我同意 :terms',
    'terms_of_service' => '服務條款',
    'email_taken' => '這個電子郵件地址已經註冊了',
    'working' => '工作中',
    'success' => '完成',
    'success_message' => '您已註冊成功! 請使用帳戶確認函中的連結驗證您的電子郵件地址。',
    'erase_data' => '您的帳號未註冊，這將使您的資料永久刪除。',
    'password' => '密碼',
    'pro_plan_product' => '專業方案',
    'pro_plan_success' => '感謝您使用 Invoice Ninja 的專業版!<p/>&nbsp;<br/>
                          <b>下一步</b><p/>一份待付的發票已寄送到您的帳號所使用的電子郵件地址
                          欲啟用專業版所有的厲害功能，請依循發票上的指示付款，以使用為期一年的專業級發票開立作業。<p/>
                         無法找到發票？需要進一步的協助? 我們樂於提供協助-- 請寫電子郵件給我們寄至 contact@invoiceninja.com',
    'unsaved_changes' => '您有尚未儲存的修改',
    'custom_fields' => '自訂欄位',
    'company_fields' => '公司欄位',
    'client_fields' => '用戶欄位',
    'field_label' => '標籤欄位',
    'field_value' => '欄位值',
    'edit' => '編輯',
    'set_name' => '設定您的公司名稱',
    'view_as_recipient' => '以收件匣模式檢視',
    'product_library' => '產品資料庫',
    'product' => '產品',
    'products' => '產品',
    'fill_products' => '自動填入之產品項目',
    'fill_products_help' => '選擇產品將自動<b>填寫描述和成本</b>',
    'update_products' => '自動更新產品',
    'update_products_help' => '更新發票時會自動 <b>更新產品資料庫</b>',
    'create_product' => '加入產品',
    'edit_product' => '編輯產品資料',
    'archive_product' => '歸檔產品資料',
    'updated_product' => '成功更新的產品資料',
    'created_product' => '建立產品資料成功',
    'archived_product' => '歸檔產品資料成功',
    'pro_plan_custom_fields' => ':link 來加入專業版，以啟用自訂欄位',
    'advanced_settings' => '進階設定',
    'pro_plan_advanced_settings' => ':link 來加入專業版，以啟用進階設定',
    'invoice_design' => '發票設計',
    'specify_colors' => '指定色彩',
    'specify_colors_label' => '選擇發票中使用的色彩',
    'chart_builder' => '圖表製作',
    'ninja_email_footer' => '由 :site 建立 | 建立、寄送、收款。',
    'go_pro' => '採用專業版',
    'quote' => '報價單',
    'quotes' => '報價單',
    'quote_number' => '報價單編號',
    'quote_number_short' => '報價單 #',
    'quote_date' => '報價單日期',
    'quote_total' => '報價單總計',
    'your_quote' => '您的報價單',
    'total' => '總計',
    'clone' => '再製',
    'new_quote' => '新報價單',
    'create_quote' => '建立報價單',
    'edit_quote' => '編輯報價單',
    'archive_quote' => '歸檔報價單',
    'delete_quote' => '刪除報價單',
    'save_quote' => '儲存報價單',
    'email_quote' => '以電子郵件傳送報價單',
    'clone_quote' => '再製到報價單',
    'convert_to_invoice' => '轉換至發票',
    'view_invoice' => '檢視發票',
    'view_client' => '檢視用戶資料',
    'view_quote' => '檢視報價單',
    'updated_quote' => '報價單更新成功',
    'created_quote' => '報價單建立成功',
    'cloned_quote' => '報價單複製成功',
    'emailed_quote' => '以電子郵件寄出報價單成功',
    'archived_quote' => '歸檔報價單成功',
    'archived_quotes' => '歸檔 :count 份報價單成功',
    'deleted_quote' => '報價單刪除成功',
    'deleted_quotes' => '刪除 :count 筆報價單成功',
    'converted_to_invoice' => '將報價單轉為發票成功',
    'quote_subject' => ':account 的第 :number 份新報價單',
    'quote_message' => '若要檢視您的 :amount 之報價單，按一下以下連結。',
    'quote_link_message' => '若要檢視您的用戶報價單，按一下以下連結:',
    'notification_quote_sent_subject' => '報價單 :invoice 已寄送給 :client',
    'notification_quote_viewed_subject' => ':client 已檢視了報價單 :invoice',
    'notification_quote_sent' => '已透過電子郵件傳送 :amount 的報價單 :invoice 給以下用戶 :client 。',
    'notification_quote_viewed' => '以下用戶 :client 檢視 :amount 的報價單 :invoice 。',
    'session_expired' => '您本次的連線已超過期限。',
    'invoice_fields' => '發票欄位',
    'invoice_options' => '發票選項',
    'hide_paid_to_date' => '隱藏迄今之付款金額',
    'hide_paid_to_date_help' => '一旦收到付款，僅在您的發票上顯示「迄今之付款金額」。',
    'charge_taxes' => '附收稅款',
    'user_management' => '管理使用者',
    'add_user' => '新增使用者',
    'send_invite' => '發送邀請',
    'sent_invite' => '寄出邀請函成功',
    'updated_user' => '更新使用者資料成功',
    'invitation_message' => '您受到 :invitor 邀請。 ',
    'register_to_add_user' => '請登入以新增使用者',
    'user_state' => '狀態',
    'edit_user' => '編輯使用者',
    'delete_user' => '刪除使用者',
    'active' => '使用中',
    'pending' => '擱置',
    'deleted_user' => '刪除使用者成功',
    'confirm_email_invoice' => '確定要電郵這發票嗎?',
    'confirm_email_quote' => '您是否確定以電子郵件寄送這份報價單?',
    'confirm_recurring_email_invoice' => '您確定您要以電郵寄送這份發票?',
    'confirm_recurring_email_invoice_not_sent' => '您確定您要啟動這項週期?',
    'cancel_account' => '刪除帳戶',
    'cancel_account_message' => '警告: 這將永久刪除您的帳戶，而且無法恢復。',
    'go_back' => '返回',
    'data_visualizations' => '資料視覺化',
    'sample_data' => '顯示的範例日期',
    'hide' => '隱藏',
    'new_version_available' => '有 :releases_link 最新的版本可用。您目前使用的是 :user_version 版，最新版是 :latest_version 版',
    'invoice_settings' => '發票設定',
    'invoice_number_prefix' => '發票號碼之前置符號',
    'invoice_number_counter' => '發票號碼計數器',
    'quote_number_prefix' => '報價單編號之前置符號',
    'quote_number_counter' => '報價單編號計數器',
    'share_invoice_counter' => '共用發票計數器',
    'invoice_issued_to' => '此發票開立給',
    'invalid_counter' => '為避免可能發生的衝突，請設定一個報價單或發票的編號前置符號',
    'mark_sent' => '標記已傳送',
    'gateway_help_1' => ':link 註冊 Authorize.net。',
    'gateway_help_2' => ':link 註冊 Authorize.net。',
    'gateway_help_17' => ':link 以取得您的 PayPal API 簽署。',
    'gateway_help_27' => ':link 以註冊 2Checkout.com。 欲確保付款能被追查，請在 2Checkout 入口網頁的 Account > Site Management 設定 :complete_link 作為重新轉向的的網址。',
    'gateway_help_60' => ':link 來建立一個 WePay 帳號。',
    'more_designs' => '更多設計',
    'more_designs_title' => '更多的發票設計',
    'more_designs_cloud_header' => '升級到專業版，以使用更多發票設計',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => '購買',
    'bought_designs' => '已成功地新增額外的設計',
    'sent' => '已傳送',
    'vat_number' => '加值稅編號',
    'timesheets' => '時間表',
    'payment_title' => '輸入您的帳單寄送地址與信用卡資料',
    'payment_cvv' => '* 這是您卡片背面的 3-4 位數字',
    'payment_footer1' => '帳單寄送地址必須與信用卡地址相同。',
    'payment_footer2' => '* 請只點擊一次"現在付款"  - 轉帳作業可能需要用 1 分鐘。',
    'id_number' => 'ID 編號',
    'white_label_link' => '白牌',
    'white_label_header' => '白牌',
    'bought_white_label' => '啟用白牌授權成功',
    'white_labeled' => '白牌',
    'restore' => '復原',
    'restore_invoice' => '復原發票',
    'restore_quote' => '復原報價單',
    'restore_client' => '復原用戶',
    'restore_credit' => '復原貸款資料',
    'restore_payment' => '復原付款資料',
    'restored_invoice' => '復原發票成功',
    'restored_quote' => '復原報價單成功',
    'restored_client' => '復原用戶資料成功',
    'restored_payment' => '復原付款資料成功',
    'restored_credit' => '復原貸款資料成功',
    'reason_for_canceling' => '告訴我們您為什麼離開，幫助我們改善我們的網站。',
    'discount_percent' => '百分比',
    'discount_amount' => '金額',
    'invoice_history' => '發票之歷程記錄',
    'quote_history' => '報價單歷史紀錄',
    'current_version' => '目前版本',
    'select_version' => '選擇版本',
    'view_history' => '檢視歷程紀錄',
    'edit_payment' => '編輯付款資料',
    'updated_payment' => '更新付款資料成功',
    'deleted' => '已刪除',
    'restore_user' => '復原使用者資料',
    'restored_user' => '復原使用者資料成功',
    'show_deleted_users' => '顯示已刪除的使用者',
    'email_templates' => '電子郵件樣範本',
    'invoice_email' => '發票電子郵件',
    'payment_email' => '付款資料電子郵件',
    'quote_email' => '報價單電子郵件',
    'reset_all' => '重設一切',
    'approve' => '同意',
    'token_billing_type_id' => '設定帳單的安全代碼',
    'token_billing_help' => '以 WePay, Stripe, Braintree 或 GoCardless 儲存詳細的付款資料。',
    'token_billing_1' => '已停用',
    'token_billing_2' => '加入 -  核取方塊顯示，但未選取',
    'token_billing_3' => '退出 - 核取方塊顯示且已選取',
    'token_billing_4' => '永遠',
    'token_billing_checkbox' => '儲存信用卡詳細資料',
    'view_in_gateway' => '在 :gateway 檢視',
    'use_card_on_file' => '使用登記之信用卡',
    'edit_payment_details' => '編輯詳細的付款資料',
    'token_billing' => '儲存卡片詳細資料',
    'token_billing_secure' => '資料已安全地由 :link 儲存',
    'support' => '支援',
    'contact_information' => '聯絡人資訊',
    '256_encryption' => '256 位元加密',
    'amount_due' => '應支付的金額',
    'billing_address' => '帳單地址',
    'billing_method' => '帳單寄送方式',
    'order_overview' => '訂單總覽',
    'match_address' => '* 地址必須與信用卡地址一致。',
    'click_once' => '* 請只點擊一次"現在付款"  - 轉帳作業可能需要用 1 分鐘。',
    'invoice_footer' => '發票頁尾',
    'save_as_default_footer' => '儲存為預設的頁尾',
    'token_management' => '管理安全代碼',
    'tokens' => '安全代碼',
    'add_token' => '新增安全代碼',
    'show_deleted_tokens' => '顯示已刪除的安全代碼',
    'deleted_token' => '刪除安全代碼成功',
    'created_token' => '安全代碼建立成功',
    'updated_token' => '更新安全代碼成功',
    'edit_token' => '編輯安全代碼',
    'delete_token' => '刪除安全代碼',
    'token' => '安全代碼',
    'add_gateway' => '新增閘道',
    'delete_gateway' => '刪除閘道資料',
    'edit_gateway' => '編輯閘道',
    'updated_gateway' => '更新閘道資料成功',
    'created_gateway' => '建立閘道資料成功',
    'deleted_gateway' => '刪除閘道資料成功',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => '信用卡',
    'change_password' => '改變密碼',
    'current_password' => '目前密碼',
    'new_password' => '新密碼',
    'confirm_password' => '確認密碼',
    'password_error_incorrect' => '目前的密碼不正確。',
    'password_error_invalid' => '這個新密碼無效。',
    'updated_password' => '更新密碼成功',
    'api_tokens' => 'API 的安全代碼',
    'users_and_tokens' => '使用者與安全代碼',
    'account_login' => '登入帳戶',
    'recover_password' => '重設您的密碼',
    'forgot_password' => '忘記您的密碼?',
    'email_address' => '電子郵件地址',
    'lets_go' => '讓我們開始',
    'password_recovery' => '重設密碼',
    'send_email' => '寄送電子郵件',
    'set_password' => '設定密碼',
    'converted' => '已轉換',
    'email_approved' => '<b>同意</b>報價單後即以電子郵件通知我',
    'notification_quote_approved_subject' => ':client 已同意報價單 :invoice',
    'notification_quote_approved' => '以下用戶 :client 同意 :amount 的報價單 :invoice。',
    'resend_confirmation' => '重寄確認註冊的電子郵件',
    'confirmation_resent' => '確認信已用電子郵件寄送',
    'gateway_help_42' => '經由 :link 註冊 BitPay。<br/>注意: 使用舊版的 API 金鑰，而非 API 的安全代碼。',
    'payment_type_credit_card' => '信用卡',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => '比特幣',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => '知識庫',
    'partial' => '存款',
    'partial_remaining' => ':balance 的 :partial',
    'more_fields' => '較多欄位',
    'less_fields' => '較少欄位',
    'client_name' => '用戶名稱',
    'pdf_settings' => 'PDF 設定',
    'product_settings' => '產品設定',
    'auto_wrap' => '自動換行',
    'duplicate_post' => '警告: 上一頁被提交兩次，第二次的提交已被略過。',
    'view_documentation' => '檢視文件',
    'app_title' => '免費、開源的線上發票管理程式',
    'app_description' => 'Invoice Ninja 是一個為消費者建立發票、帳單的免費、開源工具。 使用Invoice Ninja ，您可輕易地從任何連網裝置建立並寄送美觀的發票。 您的客戶可列印您的發票、下載其 PDF 檔案，甚至在此系統內線上付款給您。',
    'rows' => 'rows',
    'www' => 'www',
    'logo' => '標誌',
    'subdomain' => '子網域',
    'provide_name_or_email' => '請提供名字或電子郵件地址',
    'charts_and_reports' => '圖表與報告',
    'chart' => '圖表',
    'report' => '報告',
    'group_by' => '分組方式',
    'paid' => '已付款',
    'enable_report' => '報告',
    'enable_chart' => '圖表',
    'totals' => '總計',
    'run' => '執行',
    'export' => '匯出',
    'documentation' => '文件',
    'zapier' => 'Zapier',
    'recurring' => '週期性',
    'last_invoice_sent' => '上一份發票寄出於 :date',
    'processed_updates' => '已更新成功',
    'tasks' => '任務',
    'new_task' => '新任務',
    'start_time' => '開始時間',
    'created_task' => '建立工作項目成功',
    'updated_task' => '更新工作項目成功',
    'edit_task' => '編輯工作項目',
    'clone_task' => 'Clone Task',
    'archive_task' => '歸檔任務項目',
    'restore_task' => '復原任務',
    'delete_task' => '刪除工作項目',
    'stop_task' => '停止工作項目',
    'time' => '時間',
    'start' => '開始',
    'stop' => '停止',
    'now' => '現在',
    'timer' => '計時器',
    'manual' => '手動',
    'date_and_time' => '日期 & 時間',
    'second' => '秒',
    'seconds' => '秒',
    'minute' => '分',
    'minutes' => '分',
    'hour' => '時',
    'hours' => '時',
    'task_details' => '工作細節',
    'duration' => '時間長度',
    'time_log' => '時間日誌',
    'end_time' => '結束時間',
    'end' => '結束',
    'invoiced' => '已開立發票的',
    'logged' => '已登入',
    'running' => '執行中',
    'task_error_multiple_clients' => '任務不能屬於不同的用戶',
    'task_error_running' => '請先停止執行任務',
    'task_error_invoiced' => '此任務的發票已開立',
    'restored_task' => '復原任務資料成功',
    'archived_task' => '歸檔任務資料成功',
    'archived_tasks' => '歸檔 :count 項任務成功',
    'deleted_task' => '刪除任務成功',
    'deleted_tasks' => '刪除 :count 項任務成功',
    'create_task' => '建立工作項目',
    'stopped_task' => '停止任務成功',
    'invoice_task' => '為任務開立發票',
    'invoice_labels' => '發票標籤',
    'prefix' => '前置符號',
    'counter' => '計數器',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link 以註冊 Dwolla',
    'partial_value' => '必須大於零且小於總額',
    'more_actions' => '更多動作',
    'pro_plan_title' => 'Ninja 專業版',
    'pro_plan_call_to_action' => '立即升級!',
    'pro_plan_feature1' => '建立無限數量的用戶',
    'pro_plan_feature2' => '開始使用 10 種美觀的發票設計',
    'pro_plan_feature3' => '自訂 URLs - "YourBrand.InvoiceNinja.com"',
    'pro_plan_feature4' => '移除 "Created by Invoice Ninja" 字樣',
    'pro_plan_feature5' => '多使用者登入 & 追蹤活動',
    'pro_plan_feature6' => '建立報價單與專業格式的發票',
    'pro_plan_feature7' => '自訂發票欄位標題 & 編號',
    'pro_plan_feature8' => '將 PDF 附加到用戶電子郵件的選項',
    'resume' => '繼續',
    'break_duration' => '中斷',
    'edit_details' => '編輯詳細資料',
    'work' => '工作',
    'timezone_unset' => '請 :link 以設定您的時區',
    'click_here' => '按一下此處',
    'email_receipt' => '以電子郵件傳送付款收據給用戶',
    'created_payment_emailed_client' => '建立付款和透過電子郵件傳送給用戶成功',
    'add_company' => '新增公司資料',
    'untitled' => '無標題',
    'new_company' => '新的公司資料',
    'associated_accounts' => '連結的帳戶成功',
    'unlinked_account' => '取消連結的帳戶成功',
    'login' => '登入',
    'or' => 'or',
    'email_error' => '寄送郵件時發生問題',
    'confirm_recurring_timing' => '注意: 郵件已於這個小時開始時寄送。',
    'confirm_recurring_timing_not_sent' => '注意: 發票已於這個小時開始時建立。',
    'payment_terms_help' => '設定預設的 <b>發票日期</b>',
    'unlink_account' => '取消帳戶的連結',
    'unlink' => '取消連結',
    'show_address' => '顯示地址',
    'show_address_help' => '需要使用者提供其帳單地址',
    'update_address' => '更新地址',
    'update_address_help' => '使用提供的詳細資料更新用戶的地址',
    'times' => '時段',
    'set_now' => '設定為現在',
    'dark_mode' => '黑暗模式',
    'dark_mode_help' => '使用深色背景於側邊欄',
    'add_to_invoice' => '新增至發票 :invoice',
    'create_new_invoice' => '新增發票',
    'task_errors' => '請修正所有的重疊時段',
    'from' => '從',
    'to' => '到',
    'font_size' => '字型大小',
    'primary_color' => '主要色彩',
    'secondary_color' => '次要色彩',
    'customize_design' => '自訂設計',
    'content' => '內容',
    'styles' => '樣式',
    'defaults' => '預設值',
    'margins' => '邊界',
    'header' => '頁首',
    'footer' => '頁尾',
    'custom' => '自訂',
    'invoice_to' => '發票給',
    'invoice_no' => '發票編號',
    'quote_no' => '報價單編號',
    'recent_payments' => '最近的支付',
    'outstanding' => '未付清的',
    'manage_companies' => '處理公司資料',
    'total_revenue' => '總收入',
    'current_user' => '目前使用者',
    'new_recurring_invoice' => '新的週期性發票',
    'recurring_invoice' => '週期性發票',
    'new_recurring_quote' => '新的週期性報價單',
    'recurring_quote' => '週期性報價單',
    'recurring_too_soon' => '尚未到建立下一份週期性發票的時候，下一次建立發票的預定日期為 :date',
    'created_by_invoice' => '由 :invoice 建立',
    'primary_user' => '首要的使用者',
    'help' => '說明',
    'customize_help' => '<p>我們使用 :pdfmake_link 來以宣告方式定義發票的設計。 PDF 製作 :playground_link 能清楚呈現程式庫的運作。</p>
                        <p>如果您需要釋疑，請在我們的 :forum_link 就您的設計發問。</p>',
    'playground' => 'playground',
    'support_forum' => '支援討論區',
    'invoice_due_date' => '應付款日期',
    'quote_due_date' => '有效至',
    'valid_until' => '有效至',
    'reset_terms' => '重設條款',
    'reset_footer' => '重設頁尾',
    'invoice_sent' => '已寄出 :count 份發票',
    'invoices_sent' => '已寄出 :count 份發票',
    'status_draft' => '草稿',
    'status_sent' => '已傳送',
    'status_viewed' => '已檢視',
    'status_partial' => '入口頁面',
    'status_paid' => '已付款',
    'status_unpaid' => '未付款',
    'status_all' => '全部',
    'show_line_item_tax' => '顯示 <b>此項目之稅金</b>',
    'iframe_url' => '網站',
    'iframe_url_help1' => '將以下代碼複製到您的網站上的一個網頁。',
    'iframe_url_help2' => '您可按一下發票的「以收件人檢視」來測試這項功能。',
    'auto_bill' => '自動帳單',
    'military_time' => '24 小時制',
    'last_sent' => '最後寄出',
    'reminder_emails' => '提醒電郵',
    'quote_reminder_emails' => 'Quote Reminder Emails',
    'templates_and_reminders' => '範本與提醒',
    'subject' => '主旨',
    'body' => '內文',
    'first_reminder' => '首次提醒',
    'second_reminder' => '第二次提醒',
    'third_reminder' => '第三次提醒',
    'num_days_reminder' => '應付款日期之天數',
    'reminder_subject' => '提醒函: :account 的發票 :invoice',
    'reset' => '重設',
    'invoice_not_found' => '無法提供您所查詢的發票',
    'referral_program' => '推薦計劃',
    'referral_code' => '推薦的 URL',
    'last_sent_on' => '上次寄出於: :date',
    'page_expire' => '此網頁即將逾期，:click_here 以繼續作業',
    'upcoming_quotes' => '即將到期的報價單',
    'expired_quotes' => '過期的報價單',
    'sign_up_using' => '登入，使用',
    'invalid_credentials' => '這些憑證不符我們的紀錄',
    'show_all_options' => '顯示所有選項',
    'user_details' => '使用者詳細資料',
    'oneclick_login' => '已連結的帳戶',
    'disable' => '停用',
    'invoice_quote_number' => '發票與報價單編號',
    'invoice_charges' => '發票的額外費用',
    'notification_invoice_bounced' => '我們無法遞送發票 :invoice 給 :contact。',
    'notification_invoice_bounced_subject' => '無法傳送發票 :invoice',
    'notification_quote_bounced' => '我們無法遞送報價單 :invoice 給 :contact.',
    'notification_quote_bounced_subject' => '無法遞送報價單 :invoice',
    'custom_invoice_link' => '自訂發票連結',
    'total_invoiced' => '開立發票總額',
    'open_balance' => '未付的餘額',
    'verify_email' => '請用帳號確認電子郵件中的連結來驗證您的電子郵件。',
    'basic_settings' => '基本設定',
    'pro' => '專業版',
    'gateways' => '付款閘道',
    'next_send_on' => '下次寄出於:  :date',
    'no_longer_running' => '此發票並未列入排程',
    'general_settings' => '一般設定',
    'customize' => '自訂',
    'oneclick_login_help' => '連結一個帳號，不必密碼即可登入',
    'referral_code_help' => '在網路上分享我們的 APP，賺取金錢',
    'enable_with_stripe' => '啟用 | 需要刪除多餘空格',
    'tax_settings' => '稅額設定',
    'create_tax_rate' => '新增稅率',
    'updated_tax_rate' => '更新稅率成功',
    'created_tax_rate' => '已成功地建立稅率',
    'edit_tax_rate' => '編輯稅率',
    'archive_tax_rate' => '歸檔稅率',
    'archived_tax_rate' => '歸檔稅率資料成功',
    'default_tax_rate_id' => '預設稅率',
    'tax_rate' => '稅率',
    'recurring_hour' => '週期性小時',
    'pattern' => '類型',
    'pattern_help_title' => '關於類型的說明',
    'pattern_help_1' => '指定一個類型來建立消費者編號',
    'pattern_help_2' => '可用的變數:',
    'pattern_help_3' => '例如， :example 將會轉換為 :value',
    'see_options' => '查看選項',
    'invoice_counter' => '發票計數器',
    'quote_counter' => '報價單計數器',
    'type' => '類型',
    'activity_1' => ':user 已建立用戶 :client',
    'activity_2' => ':user 已將用戶 :client 歸檔',
    'activity_3' => ':user 已刪除用戶 :client',
    'activity_4' => ':user 已建立發票 :invoice',
    'activity_5' => ':user 已更新發票 :invoice',
    'activity_6' => ':user emailed invoice :invoice for :client to :contact',
    'activity_7' => ':contact viewed invoice :invoice for :client',
    'activity_8' => ':user 已將發票 :invoice 歸檔',
    'activity_9' => ':user 已刪除發票 :invoice',
    'activity_10' => ':contact entered payment :payment for :payment_amount on invoice :invoice for :client',
    'activity_11' => ':user 已更新付款資料 :payment',
    'activity_12' => ':user 已將付款資料 :payment 歸檔',
    'activity_13' => ':user 已刪除付款資料 :payment',
    'activity_14' => ':user 已輸入貸款資料 :credit',
    'activity_15' => ':user 更新貸款 :credit',
    'activity_16' => ':user 已將 :credit 貸款資料歸檔',
    'activity_17' => ':user 已刪除 :credit 貸款資料',
    'activity_18' => ':user 已建立報價單 :quote',
    'activity_19' => ':user 已更新報價單 :quote',
    'activity_20' => ':user emailed quote :quote for :client to :contact',
    'activity_21' => ':contact 已檢視報價單 :quote',
    'activity_22' => ':user 已將報價單 :quote 歸檔',
    'activity_23' => ':user 已刪除發票 :quote',
    'activity_24' => ':user 已復原報價單 :quote',
    'activity_25' => ':user 已復原發票 :invoice',
    'activity_26' => ':user 已復原用戶 :client 資料',
    'activity_27' => ':user 已復原付款資料 :payment',
    'activity_28' => ':user 已復原 :credit 貸款資料',
    'activity_29' => ':contact approved quote :quote for :client',
    'activity_30' => ':user 已建立供應商 :vendor',
    'activity_31' => ':user 已將供應商 :vendor 歸檔',
    'activity_32' => ':user 已刪除供應商 :vendor',
    'activity_33' => ':user 已復原供應商 :vendor',
    'activity_34' => ':user 已建立支出 :expense',
    'activity_35' => ':user 已將支出 :expense 歸檔',
    'activity_36' => ':user 已刪除支出 :expense',
    'activity_37' => ':user 已復原支出 :expense',
    'activity_42' => ':user 已建立任務 :task',
    'activity_43' => ':user 已將任務 :task 更新',
    'activity_44' => ':user 已將任務 :task 歸檔',
    'activity_45' => ':user 已刪除任務 :task',
    'activity_46' => ':user 已將任務 :task復原',
    'activity_47' => ':user 已將支出 :expense 更新',
    'activity_48' => ':user 已更新票證 :ticket',
    'activity_49' => ':user 已關閉票證 :ticket',
    'activity_50' => ':user 已合併票證 :ticket',
    'activity_51' => ':user 拆分票證 :ticket',
    'activity_52' => ':contact 已開啟票證 :ticket',
    'activity_53' => ':contact 已重新開啟票證 :ticket',
    'activity_54' => ':user 已重新開啟票證 :ticket',
    'activity_55' => ':contact 已回覆票證 :ticket',
    'activity_56' => ':user 已檢視票證 :ticket',

    'payment' => '付款',
    'system' => '系統',
    'signature' => '電子郵件簽名',
    'default_messages' => '預設的訊息',
    'quote_terms' => '報價單條款',
    'default_quote_terms' => '預設的報價單條款',
    'default_invoice_terms' => '預設的發票條款',
    'default_invoice_footer' => '預設的發票頁尾',
    'quote_footer' => '報價單頁尾',
    'free' => '免費',
    'quote_is_approved' => '已獲同意',
    'apply_credit' => '套用貸款',
    'system_settings' => '系統設定',
    'archive_token' => '歸檔安全代碼',
    'archived_token' => '歸檔安全代碼成功',
    'archive_user' => '歸檔使用者資料',
    'archived_user' => '歸檔使用者資料成功',
    'archive_account_gateway' => '刪除閘道資料',
    'archived_account_gateway' => '封存閘道資料成功',
    'archive_recurring_invoice' => '歸檔週期性發票',
    'archived_recurring_invoice' => '歸檔週期性發票成功',
    'delete_recurring_invoice' => '刪除週期性發票',
    'deleted_recurring_invoice' => '刪除週期性發票成功',
    'restore_recurring_invoice' => '復原週期性發票',
    'restored_recurring_invoice' => '復原週期性發票成功',
    'archive_recurring_quote' => '歸檔週期性報價單',
    'archived_recurring_quote' => '歸檔週期性報價單成功',
    'delete_recurring_quote' => '刪除週期性報價單',
    'deleted_recurring_quote' => '刪除週期性報價單成功',
    'restore_recurring_quote' => '復原週期性報價單',
    'restored_recurring_quote' => '還原週期性報價單成功',
    'archived' => '已歸檔',
    'untitled_account' => '無名稱的公司',
    'before' => '之前',
    'after' => '之後',
    'reset_terms_help' => '重設至預設的帳戶條款',
    'reset_footer_help' => '重設至預設的帳戶頁尾',
    'export_data' => '匯出資料',
    'user' => '使用者',
    'country' => '國家',
    'include' => '包含',
    'logo_too_large' => '您的標誌大小為 :size，我們建議您上傳一個小於 200KB 的圖片檔案以改善 PDF 的效能',
    'import_freshbooks' => '從 FreshBooks 匯入',
    'import_data' => '匯入資料',
    'source' => '來源',
    'csv' => 'CSV',
    'client_file' => '用戶檔案',
    'invoice_file' => '發票檔案',
    'task_file' => '任務檔案',
    'no_mapper' => '此檔案的對應無效',
    'invalid_csv_header' => '無效的 CSV 標頭',
    'client_portal' => '用戶門戶頁面',
    'admin' => '管理者',
    'disabled' => '已停用',
    'show_archived_users' => '顯示歸檔的使用者資料',
    'notes' => '註記',
    'invoice_will_create' => '將會建立發票',
    'invoices_will_create' => '將會建立發票',
    'failed_to_import' => '無法載入以下的紀錄，它們已存在或缺少必填的欄位。',
    'publishable_key' => '可公開的金鑰',
    'secret_key' => '秘密金鑰',
    'missing_publishable_key' => '設定您的 Stripe 可公開金鑰以提昇結帳手續',
    'email_design' => '電子郵件的設計',
    'due_by' => ':date之前應付款',
    'enable_email_markup' => '啟用網頁標示',
    'enable_email_markup_help' => '透過在電子郵件中加入 schema.org 標記，使您的用戶更輕鬆地支付您的費用。',
    'template_help_title' => '範本說明',
    'template_help_1' => '可用的變數:',
    'email_design_id' => '電子郵件樣式',
    'email_design_help' => '使用 HTML 的呈現方式，讓您的電子郵件看起來更專業。',
    'plain' => '純文字',
    'light' => '淺色',
    'dark' => '深色',
    'industry_help' => '以此對照小型公司與產業的平均值。',
    'subdomain_help' => '設定子網域或在您的網站上顯示發票。',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => '設定一個前置符號或使用自訂樣式，以動態地設定發票號碼。',
    'quote_number_help' => '設定一個前置符號或使用自訂樣式，以動態地設定報價單號碼。',
    'custom_client_fields_helps' => '在建立用戶時加入欄位，並選擇性在 PDF 上顯示標籤和值。',
    'custom_account_fields_helps' => '增加一組項目名稱與值到 PDF的 公司詳細資料區。',
    'custom_invoice_fields_helps' => '於建立一份發票時增加欄位，且可選擇在 PDF 檔案顯示欄位名稱與值。',
    'custom_invoice_charges_helps' => '該欄位的在建立一筆客戶資料時新增欄位，且在發票小計中加入費用。',
    'token_expired' => '認證用的安全代碼已過期。 請再試一遍。',
    'invoice_link' => '發票的連結',
    'button_confirmation_message' => '按一下以確認您的郵件地址。',
    'confirm' => '確認',
    'email_preferences' => '電子郵件偏好設定',
    'created_invoices' => '建立 :count 筆發票成功',
    'next_invoice_number' => '下一個發票號碼是 :number.',
    'next_quote_number' => '下一個報價單號碼是 :number.',
    'days_before' => '於此之前的天數',
    'days_after' => '於此之後的天數',
    'field_due_date' => '應付款日期',
    'field_invoice_date' => '發票日期',
    'schedule' => '時間表',
    'email_designs' => '電子郵件的樣式設計',
    'assigned_when_sent' => '在寄送時指定',
    'white_label_purchase_link' => '購買白牌授權',
    'expense' => '支出',
    'expenses' => '支出',
    'new_expense' => '輸入支出',
    'enter_expense' => '輸入支出',
    'vendors' => '供應商',
    'new_vendor' => '新供應商',
    'payment_terms_net' => '淨額',
    'vendor' => '供應商',
    'edit_vendor' => '編輯供應商',
    'archive_vendor' => '歸檔供應商',
    'delete_vendor' => '刪除供應商',
    'view_vendor' => '檢視供應商',
    'deleted_expense' => '刪除支出項目成功',
    'archived_expense' => '歸檔支出項目成功',
    'deleted_expenses' => '刪除支出項目成功',
    'archived_expenses' => '歸檔支出項目成功',
    'expense_amount' => '支出金額',
    'expense_balance' => '支出餘額',
    'expense_date' => '支出日期',
    'expense_should_be_invoiced' => '應否為這項支出開立發票?',
    'public_notes' => '公開註記',
    'invoice_amount' => '發票金額',
    'exchange_rate' => '匯率',
    'yes' => '是',
    'no' => '否',
    'should_be_invoiced' => '應為此開立發票',
    'view_expense' => '檢視支出 # :expense',
    'edit_expense' => '編輯支出',
    'archive_expense' => '歸檔支出資料',
    'delete_expense' => '刪除支出',
    'view_expense_num' => '支出 # :expense',
    'updated_expense' => '更新支出資料成功',
    'created_expense' => '已成功建立支出',
    'enter_expense' => '輸入支出',
    'view' => '檢視',
    'restore_expense' => '復原支出資料',
    'invoice_expense' => '為支出開立發票',
    'expense_error_multiple_clients' => '費用不能屬於不同的用戶',
    'expense_error_invoiced' => '已開立發票的支出',
    'convert_currency' => '轉換貨幣單位',
    'num_days' => '天數',
    'create_payment_term' => '建立付款條件',
    'edit_payment_terms' => '編輯付款條件',
    'edit_payment_term' => '編輯付款條件',
    'archive_payment_term' => '歸檔付款條件',
    'recurring_due_dates' => '週期性發票之應付款日期',
    'recurring_due_date_help' => '<p>為發票自動設定一個應付款日期。</p>
        <p>以月或年為週期而循環產生、且設定的應付款日先於或等於發票建立日在下個月份收款。若應付款日設定為每月第29日或第30日、但當月份並無該日時，應付款日期為該月份的最後一日。</p>
        <p>以星期為週期而循環產生、且應付款日設定為在該星期中的發票建立日的在下一個星期收款。
        <p>例如: </p>
        <ul>
          <li>今天為第15天，應付款日為每月的第1日，付款日為下一月份的第1日。</li>
          <li>今天為第15天，應付款日為每月的最後一日，付款日為該月份的最後一日。
</li>
          <li>今天為第15天，應付款日為每月的第15日，付款日為 <strong>下一個</strong>月份的第15日。
</li>
          <li>今天為星期五，應付款日為其後的第1個星期五。付款日為下一個星期五，而非今日>
</li>
        </ul>',
    'due' => '應付款',
    'next_due_on' => '下次應付款: :date',
    'use_client_terms' => '使用用戶條款',
    'day_of_month' => '每月的 :ordinal 日',
    'last_day_of_month' => '月份的最後一日',
    'day_of_week_after' => ':ordinal :day 之後',
    'sunday' => '星期日',
    'monday' => '星期一',
    'tuesday' => '星期二',
    'wednesday' => '星期三',
    'thursday' => '星期四',
    'friday' => '星期五',
    'saturday' => '星期六',
    'header_font_id' => 'Header 的字型',
    'body_font_id' => 'Body 的字型',
    'color_font_help' => '注意: 主要色彩和字型也用於用戶門戶頁面和自訂電子郵件設計。',
    'live_preview' => '即時預覽',
    'invalid_mail_config' => '無法寄出郵件，請檢查郵件設定是否正確。',
    'invoice_message_button' => '若要檢視您的 :amount 之發票，按一下以下按鈕。',
    'quote_message_button' => '若要檢視您的 :amount 之報價單，按一下以下按鈕。',
    'payment_message_button' => '感謝您支付 :amount 元。',
    'payment_type_direct_debit' => '直接扣款',
    'bank_accounts' => '信用卡與銀行',
    'add_bank_account' => '新增銀行帳號',
    'setup_account' => '設定帳號',
    'import_expenses' => '匯入支出資料',
    'bank_id' => '銀行',
    'integration_type' => '整合模式',
    'updated_bank_account' => '更新銀行帳號成功',
    'edit_bank_account' => '編輯銀行帳號',
    'archive_bank_account' => '歸檔銀行帳號',
    'archived_bank_account' => '歸檔銀行帳號成功',
    'created_bank_account' => '已成功建立銀行帳號',
    'validate_bank_account' => '有效的銀行帳號',
    'bank_password_help' => '注意: 您的密碼已安全地傳輸，而且絕不會儲存在我們的伺服器。',
    'bank_password_warning' => '警告: 您的密碼可能以純文字格式傳輸，建議您啟用 HTTPS。',
    'username' => '使用者名稱',
    'account_number' => '帳號號碼',
    'account_name' => '帳號名稱',
    'bank_account_error' => '無法檢索帳戶詳細資訊，請檢查您的認證。',
    'status_approved' => '已核准',
    'quote_settings' => '報價單設定',
    'auto_convert_quote' => '自動轉換',
    'auto_convert_quote_help' => '在用戶核准後自動將報價單轉換為發票。',
    'validate' => '有效的',
    'info' => '資訊',
    'imported_expenses' => '已成功建立 :count_vendors (筆) 供應商資料以及 :count_expenses (筆) 支出資料',
    'iframe_url_help3' => '注意: 如果您計畫接受信用卡，我們極力建議在您的網站啟用 HTTPS。',
    'expense_error_multiple_currencies' => '支出不可同時使用不同的貨幣。',
    'expense_error_mismatch_currencies' => '用戶的貨幣與支出貨幣不相符。',
    'trello_roadmap' => 'Trello 路徑圖',
    'header_footer' => 'Header/Footer',
    'first_page' => '第一頁',
    'all_pages' => '所有頁面',
    'last_page' => '最後一頁',
    'all_pages_header' => '顯示頁首於',
    'all_pages_footer' => '顯示頁尾於',
    'invoice_currency' => '發票使用的貨幣',
    'enable_https' => '我們強烈建議在接收信用卡詳細資料時使用 HTTPS。',
    'quote_issued_to' => '報價單給',
    'show_currency_code' => '貨幣代碼',
    'free_year_message' => '您的帳號已免費升級到效期一年的專業版。',
    'trial_message' => '您的帳號將可試用我們的專業版，為期兩星期。',
    'trial_footer' => '您的專業滿免費試用期還有 :count 天， :link 立即升級。',
    'trial_footer_last_day' => '今天是您的專業滿免費試用期的最後一日， :link 立即升級。',
    'trial_call_to_action' => '開始免費試用',
    'trial_success' => '啟用兩星期的專業版免費試用成功',
    'overdue' => '逾期未付',


    'white_label_text' => '購買一年的白牌授權 $:price，從發票和用戶門戶頁面中移除 Invoice Ninja 品牌。',
    'user_email_footer' => '欲調整您的電子郵件通知設定。請造訪 :link',
    'reset_password_footer' => '若您未提出這項重設密碼的要求，請寫電子郵件給我們的客服: :email',
    'limit_users' => '抱歉，這將超過 :limit 名使用者的限制',
    'more_designs_self_host_header' => '僅用 $:price 即可取得額外 6 種發票樣式設計',
    'old_browser' => '請使用 :link',
    'newer_browser' => '較新的瀏覽器',
    'white_label_custom_css' => '點此 :link 支付 $:price 以自訂樣式並協助支持我們的專案。',
    'bank_accounts_help' => '連接銀行帳戶以自動匯入支出並建立供應商。 支援美國運通和 :link。',
    'us_banks' => '400 家以上的美國銀行',

    'pro_plan_remove_logo' => ':link 來加入專業版，以移除 Invoice Ninja 標誌',
    'pro_plan_remove_logo_link' => '按一下此處',
    'invitation_status_sent' => '已傳送',
    'invitation_status_opened' => '已開啟',
    'invitation_status_viewed' => '已檢視',
    'email_error_inactive_client' => '無法將電子郵件傳送到未使用中用戶',
    'email_error_inactive_contact' => '無法寄送郵件到註冊未生效之通聯地址',
    'email_error_inactive_invoice' => '無法寄送郵件給註冊未生效之發票',
    'email_error_inactive_proposal' => '無法寄送郵件到註冊未生效的提案者',
    'email_error_user_unregistered' => '請註冊您的帳戶以便寄送電子郵件',
    'email_error_user_unconfirmed' => '請確認您的帳戶以便寄送電子郵件',
    'email_error_invalid_contact_email' => '無效的聯絡人電子郵件',

    'navigation' => '導覽',
    'list_invoices' => '列出所有發票',
    'list_clients' => '列出用戶',
    'list_quotes' => '列出所有報價單',
    'list_tasks' => '列出所有任務',
    'list_expenses' => '列出所有支出',
    'list_recurring_invoices' => '列出週期性發票',
    'list_payments' => '列出所有付款資料',
    'list_credits' => '列出貸款資料',
    'tax_name' => '稅名',
    'report_settings' => '報告設定',
    'search_hotkey' => '快速鍵為 /',

    'new_user' => '新使用者',
    'new_product' => '新產品',
    'new_tax_rate' => '新稅率',
    'invoiced_amount' => '已開立發票之金額',
    'invoice_item_fields' => '發票項目欄位',
    'custom_invoice_item_fields_help' => '於建立發票品項時增加欄位，並在 PDF 檔案顯示欄位名稱與值。',
    'recurring_invoice_number' => '週期性編號',
    'recurring_invoice_number_prefix_help' => 'Specify a prefix to be added to the invoice number for recurring invoices.',

    // Client Passwords
    'enable_portal_password' => '用以保護發票的密碼',
    'enable_portal_password_help' => '使您能夠為每位聯絡人設定密碼。若設定密碼，聯絡人將會在查看發票之前被要求輸入密碼。',
    'send_portal_password' => '自動產生',
    'send_portal_password_help' => '若無設定密碼，則隨第一份發票自動產生一個，並將隨發票一同寄出。',

    'expired' => '過期',
    'invalid_card_number' => '這個信用卡號碼不正確。',
    'invalid_expiry' => '這個有效日期不正確。',
    'invalid_cvv' => 'CVV 不正確。',
    'cost' => '成本',
    'create_invoice_for_sample' => '注意: 建立您的第一份發票以在此預覽。',

    // User Permissions
    'owner' => '擁有者',
    'administrator' => '管理者',
    'administrator_help' => '允許使用者管理所有使用者、改變設定、修改所有紀錄',
    'user_create_all' => '建立客戶、發票等',
    'user_view_all' => '檢視所有用戶資料、發票等',
    'user_edit_all' => '編輯所有用戶資料、發票等',
    'gateway_help_20' => ':link 以註冊 Sage Pay。',
    'gateway_help_21' => ':link 以註冊 Sage Pay。',
    'partial_due' => '部分應付款',
    'restore_vendor' => '復原供應商',
    'restored_vendor' => '復原供應商成功',
    'restored_expense' => '復原支出資料成功',
    'permissions' => '權限',
    'create_all_help' => '允許使用者建立與更改紀錄',
    'view_all_help' => '允許使用者查看不是他們所建立的紀錄',
    'edit_all_help' => '允許使用者修改不是他們所建立的紀錄',
    'view_payment' => '檢視付款資料',

    'january' => '一月',
    'february' => '二月',
    'march' => '三月',
    'april' => '四月',
    'may' => '五月',
    'june' => '六月',
    'july' => '七月',
    'august' => '八月',
    'september' => '九月',
    'october' => '十月',
    'november' => '十一月',
    'december' => '十二月',

    // Documents
    'documents_header' => '文件:',
    'email_documents_header' => '文件:',
    'email_documents_example_1' => 'Receipt.pdf 小工具',
    'email_documents_example_2' => '最後可寄送的 .zip',
    'quote_documents' => '報價單文件',
    'invoice_documents' => '發票文件',
    'expense_documents' => '支出文件',
    'invoice_embed_documents' => '嵌入的文件',
    'invoice_embed_documents_help' => '在發票上附加圖片。',
    'document_email_attachment' => '附加文件',
    'ubl_email_attachment' => '附加 UBL',
    'download_documents' => '下載文件 (:size)',
    'documents_from_expenses' => '從支出:',
    'dropzone_default_message' => '將檔案拖曳至此或點擊此處來上傳',
    'dropzone_default_message_disabled' => '已停用上傳',
    'dropzone_fallback_message' => '您的瀏覽器不支援拖曳上傳檔案的功能。',
    'dropzone_fallback_text' => '請使用以下的備援表單，像從前那樣上傳您的檔案。',
    'dropzone_file_too_big' => '檔案太大 ({{filesize}}MiB)。 檔案大小的上限: {{maxFilesize}}MiB。',
    'dropzone_invalid_file_type' => '您不能上傳這種檔案。',
    'dropzone_response_error' => '伺服器回應代碼為 {{statusCode}} 。',
    'dropzone_cancel_upload' => '取消上傳',
    'dropzone_cancel_upload_confirmation' => '您確定要取消這次的上傳?',
    'dropzone_remove_file' => '移除檔案',
    'documents' => '文件',
    'document_date' => '文件日期',
    'document_size' => '大小',

    'enable_client_portal' => '用戶門戶頁面',
    'enable_client_portal_help' => '顯示/隱藏用戶門戶頁面。',
    'enable_client_portal_dashboard' => '儀表板',
    'enable_client_portal_dashboard_help' => '在用戶門戶頁面顯示/隱藏儀表板頁。',

    // Plans
    'account_management' => '帳號管理',
    'plan_status' => '訂用的合約狀態',

    'plan_upgrade' => '升級',
    'plan_change' => '改變方案',
    'pending_change_to' => '改為',
    'plan_changes_to' => ':plan 於 :date',
    'plan_term_changes_to' => ':plan (:term) 於 :date',
    'cancel_plan_change' => '取消更改',
    'plan' => '資費案',
    'expires' => '到期',
    'renews' => '更新',
    'plan_expired' => ':plan 方案已過期',
    'trial_expired' => ':plan 版本試用已結束',
    'never' => '永不',
    'plan_free' => '免費',
    'plan_pro' => '專業版',
    'plan_enterprise' => '企業',
    'plan_white_label' => '自行架設網站 (白牌)',
    'plan_free_self_hosted' => '自行架設網站 (免費)',
    'plan_trial' => '試用',
    'plan_term' => '條款',
    'plan_term_monthly' => '每月',
    'plan_term_yearly' => '每年',
    'plan_term_month' => '月',
    'plan_term_year' => '年',
    'plan_price_monthly' => '$:price/月',
    'plan_price_yearly' => '$:price/年',
    'updated_plan' => '更新版本設定',
    'plan_paid' => '效期開始於',
    'plan_started' => '選用版本的效期開始於',
    'plan_expires' => '選用版本的效期開始於',

    'white_label_button' => '白牌',

    'pro_plan_year_description' => '訂用 Invoice Ninja 專業版一年方案。',
    'pro_plan_month_description' => '訂用 Invoice Ninja 專業版一個月方案。',
    'enterprise_plan_product' => '企業方案',
    'enterprise_plan_year_description' => '訂用 Invoice Ninja 企業版一年方案。',
    'enterprise_plan_month_description' => '訂用 Invoice Ninja 企業版一個月方案。',
    'plan_credit_product' => '貸款',
    'plan_credit_description' => '未使用時間的貸款',
    'plan_pending_monthly' => '將於 :date 切換至月租型',
    'plan_refunded' => '已發送一筆退款。',

    'live_preview' => '即時預覽',
    'page_size' => '頁面尺寸',
    'live_preview_disabled' => '為支援選用的字型，已停用即時預覽',
    'invoice_number_padding' => '未定的',
    'preview' => '預覽',
    'list_vendors' => '列出供應商',
    'add_users_not_supported' => '升級至企業版，以在您的帳號增加額外的使用者。',
    'enterprise_plan_features' => '企業版進一步支援多使用者與附加檔案， :link 以查看其所有的功能一覽表。',
    'return_to_app' => '返回 APP',


    // Payment updates
    'refund_payment' => '已退款的支付',
    'refund_max' => '最大值:',
    'refund' => '退款',
    'are_you_sure_refund' => '退還所選擇的付款?',
    'status_pending' => '擱置',
    'status_completed' => '完成',
    'status_failed' => '失敗',
    'status_partially_refunded' => '部分退款',
    'status_partially_refunded_amount' => '退還 :amount',
    'status_refunded' => '退款',
    'status_voided' => '已取消',
    'refunded_payment' => '已退款的付款',
    'activity_39' => ':user 已取消一項 :payment_amount 的付款 :payment',
    'activity_40' => ':user 獲得一筆金額 :payment_amount 付款 :payment 的退款 :adjustment',
    'card_expiration' => '到期:&nbsp:expires',

    'card_creditcardother' => '未知的',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => '大來卡',
    'card_discover' => 'Discover卡',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser 卡',
    'card_maestro' => 'Maestro 卡',
    'card_mastercard' => '萬事達卡',
    'card_solo' => 'Solo 卡',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa卡',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => '接受美國銀行轉帳',
    'stripe_ach_help' => '必須以 :link 啟用 ACH 的支援功能。',
    'ach_disabled' => '另一個直接扣款的閘道已設定。',

    'plaid' => 'Plaid',
    'client_id' => '用戶 Id',
    'secret' => '秘密',
    'public_key' => '公開金鑰',
    'plaid_optional' => '(選擇性的)',
    'plaid_environment_help' => 'Stripe 測試金鑰一旦發送，即可使用 Plaid 的開發環境 (tartan)。',
    'other_providers' => '其他供應商',
    'country_not_supported' => '該國家不受支援。',
    'invalid_routing_number' => '此流水號無效。',
    'invalid_account_number' => '此帳號號碼無效。',
    'account_number_mismatch' => '此帳號號碼不符。',
    'missing_account_holder_type' => '請選擇一個個人或公司的帳號。',
    'missing_account_holder_name' => '請輸入帳號持有者的名字。',
    'routing_number' => '流水號碼',
    'confirm_account_number' => '確認帳戶號碼',
    'individual_account' => '個人帳號',
    'company_account' => '公司帳號',
    'account_holder_name' => '帳戶持有人之',
    'add_account' => '新增帳號',
    'payment_methods' => '付款方式',
    'complete_verification' => '完成驗證',
    'verification_amount1' => '金額 1',
    'verification_amount2' => '金額 2',
    'payment_method_verified' => '已成功完成驗證',
    'verification_failed' => '驗證失敗',
    'remove_payment_method' => '移除付款方式',
    'confirm_remove_payment_method' => '您是否確定移除這個付款方式?',
    'remove' => '刪除',
    'payment_method_removed' => '已移除的付款方式。',
    'bank_account_verification_help' => '我們已存兩筆名義為「驗證」的款項到您的帳戶。這些存款需等 1-2 個工作天才會出現在您的對帳單。請輸入以下的金額。',
    'bank_account_verification_next_steps' => '我們已存兩筆名義為「驗證」的款項到您的帳戶。這些存款需等1-2個工作天才會出現在您的對帳單。
一旦您收到這兩筆款項，請回到這個付款方式頁面，並點擊帳號旁邊的「完成驗證」。',
    'unknown_bank' => '未知的銀行',
    'ach_verification_delay_help' => '您在完成驗證後可使用此帳號。 驗證通常需要 1-2 個工作天。',
    'add_credit_card' => '新增信用卡',
    'payment_method_added' => '新增付款方式。',
    'use_for_auto_bill' => '用於自動帳單',
    'used_for_auto_bill' => '自動帳單付款方式',
    'payment_method_set_as_default' => '設定自動帳單付款方式。',
    'activity_41' => ':payment_amount 的付款 (:payment) 失敗',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => '您必須 :link。',
    'stripe_webhook_help_link_text' => '新增此 URL 為 Stripe 的終端',
    'gocardless_webhook_help_link_text' => '新增此 URL 為 GoCardless 的終端',
    'payment_method_error' => '在新增您的付款方式時發生錯誤。請稍後再試。',
    'notification_invoice_payment_failed_subject' => '發票 :invoice 之付款失敗',
    'notification_invoice_payment_failed' => '用戶:client 支付的款項，發票 :invoice 失敗。 付款已標記為失敗，並且 :amount 已加入到用戶的餘額。',
    'link_with_plaid' => '立即將帳號連結 Plaid',
    'link_manually' => '手動連結',
    'secured_by_plaid' => '已受Plaid保障安全',
    'plaid_linked_status' => '您在 :bank的銀行帳號',
    'add_payment_method' => '新增付款方式',
    'account_holder_type' => '帳戶持有人類別',
    'ach_authorization' => '我授權: 公司使用我的銀行帳戶進行未來的付款, 並在必要時以電子方式將我的帳戶記入, 以糾正錯誤的借項。我知道我可以隨時通過刪除付款條件或聯繫: 電子郵件來取消此授權。',
    'ach_authorization_required' => '您必須同意 ACH 轉帳。',
    'off' => '關',
    'opt_in' => '加入',
    'opt_out' => '退出',
    'always' => '永遠',
    'opted_out' => '退出',
    'opted_in' => '加入',
    'manage_auto_bill' => '管理自動',
    'enabled' => '啟用',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => '透過 BrainTree 啟用 PayPal 付款',
    'braintree_paypal_disabled_help' => 'PayPal 閘道正在處理PayPal 付款',
    'braintree_paypal_help' => '您必須也 :link。',
    'braintree_paypal_help_link_text' => '將 PayPal 連結至您的 BrainTree 帳號',
    'token_billing_braintree_paypal' => '儲存付款的詳細資料',
    'add_paypal_account' => '新增 PayPal 帳戶',


    'no_payment_method_specified' => '無指定之付款方式',
    'chart_type' => '圖表類型',
    'format' => '格式',
    'import_ofx' => '載入 OFX',
    'ofx_file' => 'OFX 檔案',
    'ofx_parse_failed' => '分析 OFX 檔案失敗',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => '透過 WePay 登入',
    'use_another_provider' => '使用另一個供應商',
    'company_name' => '公司名稱',
    'wepay_company_name_help' => '這將出現在客戶的信用卡帳單上。',
    'wepay_description_help' => '這份報告的目的。',
    'wepay_tos_agree' => '我同意 :link。',
    'wepay_tos_link_text' => 'WePay 之服務條款',
    'resend_confirmation_email' => '重寄確認註冊的電子郵件',
    'manage_account' => '管理帳號',
    'action_required' => '需要執行的動作',
    'finish_setup' => '結束設定',
    'created_wepay_confirmation_required' => '請檢查您的電子信箱並以WePay確認您的電子郵件地址。',
    'switch_to_wepay' => '切換至 WePay',
    'switch' => 'Switch',
    'restore_account_gateway' => '復原閘道',
    'restored_account_gateway' => '復原閘道成功',
    'united_states' => '美國',
    'canada' => '加拿大',
    'accept_debit_cards' => '接受簽帳金融卡',
    'debit_cards' => '簽帳金融卡',

    'warn_start_date_changed' => '下一份發票將於新的起始日期寄出。',
    'warn_start_date_changed_not_sent' => '下一份發票將於新的起始日期建立。',
    'original_start_date' => '原來的起始日期',
    'new_start_date' => '新的起始日期',
    'security' => '安全',
    'see_whats_new' => '查看 :version 版的更新',
    'wait_for_upload' => '請等待檔案上傳結束。',
    'upgrade_for_permissions' => '升級到我們的企業版以獲得權限。',
    'enable_second_tax_rate' => '啟用 <b>第二項稅率</b>的設定',
    'payment_file' => '付款資料的檔案',
    'expense_file' => '支出資料的檔案',
    'product_file' => '產品檔案',
    'import_products' => '匯入產品資料',
    'products_will_create' => '將會建立產品',
    'product_key' => '產品',
    'created_products' => '建立/更新 :count (項) 產品資料成功',
    'export_help' => '若您計畫匯入資料到 Invoice Ninja ，請使用JSON。<br/>該檔案包含關於用戶、產品、發票、報價單與付款的資料。',
    'selfhost_export_help' => '<br/>我們建議使用 mysqldump 來建立一個完整的備份。',
    'JSON_file' => 'JSON檔案',

    'view_dashboard' => '檢視儀表板',
    'client_session_expired' => '連線已超過期限',
    'client_session_expired_message' => '您的連線已超過期限。請再次點擊您的電子郵件連結。',

    'auto_bill_notification' => '此發票將會自動地於 :due_date在您登記的 :payment_method 結帳。',
    'auto_bill_payment_method_bank_transfer' => '銀行帳戶',
    'auto_bill_payment_method_credit_card' => '信用卡',
    'auto_bill_payment_method_paypal' => 'PayPal 帳戶',
    'auto_bill_notification_placeholder' => '將於應付款日自動從您登錄的信用卡收取此發票的款項。',
    'payment_settings' => '付款設定',

    'on_send_date' => '於寄出日',
    'on_due_date' => '於應付款日',
    'auto_bill_ach_date_help' => '代收代付服務將自動在應付款日收款。',
    'warn_change_auto_bill' => '由於全國自動票據交換所協會的規定，此發票的更改將會使代收代付服務無法自動收款。',

    'bank_account' => '銀行帳戶',
    'payment_processed_through_wepay' => 'ACH 付款將以 WePay 進行。',
    'wepay_payment_tos_agree' => '我同意 WePay 的 :terms 與 :privacy_policy。',
    'privacy_policy' => '隱私權政策',
    'wepay_payment_tos_agree_required' => '您必須同意 WePay 的服務條款與隱私權政策。',
    'ach_email_prompt' => '請輸入您的電子郵件地址:',
    'verification_pending' => '認證作業處理中',

    'update_font_cache' => '請強制刷新頁面以更新字型快取。',
    'more_options' => '更多選項',
    'credit_card' => '信用卡',
    'bank_transfer' => '銀行轉帳',
    'no_transaction_reference' => '我們未從這個閘道收到付款轉帳資料。',
    'use_bank_on_file' => '使用已登記的銀行',
    'auto_bill_email_message' => '此發票的款項將會自動地在付款日以登記的付款方式收取。',
    'bitcoin' => '比特幣',
    'gocardless' => 'GoCardless',
    'added_on' => '新增 :date',
    'failed_remove_payment_method' => '移除付款方式失敗',
    'gateway_exists' => '閘道已存在',
    'manual_entry' => '手動輸入',
    'start_of_week' => '每星期的第一天',

    // Frequencies
    'freq_inactive' => '停用',
    'freq_daily' => '每天',
    'freq_weekly' => '每星期',
    'freq_biweekly' => '每兩周',
    'freq_two_weeks' => '兩星期',
    'freq_four_weeks' => '四星期',
    'freq_monthly' => '每月',
    'freq_three_months' => '三個月',
    'freq_four_months' => '四個月',
    'freq_six_months' => '六個月',
    'freq_annually' => 'Annually',
    'freq_two_years' => '兩年',

    // Payment types
    'payment_type_Apply Credit' => '套用貸款',
    'payment_type_Bank Transfer' => '銀行轉帳',
    'payment_type_Cash' => '現金',
    'payment_type_Debit' => '簽帳卡',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa 卡',
    'payment_type_MasterCard' => '萬事達卡',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => '發現卡',
    'payment_type_Diners Card' => '大來卡',
    'payment_type_EuroCard' => '歐洲卡',
    'payment_type_Nova' => 'Nova 卡',
    'payment_type_Credit Card Other' => '其它信用卡',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google 錢包',
    'payment_type_Check' => '支票',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser 卡',
    'payment_type_Maestro' => 'Maestro 卡',
    'payment_type_Solo' => 'Solo 卡',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => '比特幣',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => '會計與法務',
    'industry_Advertising' => '廣告',
    'industry_Aerospace' => '航太工業',
    'industry_Agriculture' => '農業',
    'industry_Automotive' => '汽車工業',
    'industry_Banking & Finance' => '銀行與保險',
    'industry_Biotechnology' => '生物科技',
    'industry_Broadcasting' => '傳播',
    'industry_Business Services' => '商業服務',
    'industry_Commodities & Chemicals' => '化學產品',
    'industry_Communications' => '通訊',
    'industry_Computers & Hightech' => '電腦與高科技',
    'industry_Defense' => '國防',
    'industry_Energy' => '能源',
    'industry_Entertainment' => '娛樂',
    'industry_Government' => '政府',
    'industry_Healthcare & Life Sciences' => '醫療保健與生命科學',
    'industry_Insurance' => '保險',
    'industry_Manufacturing' => '製造業',
    'industry_Marketing' => '行銷',
    'industry_Media' => '媒體',
    'industry_Nonprofit & Higher Ed' => '非營利與高等教育',
    'industry_Pharmaceuticals' => '藥品',
    'industry_Professional Services & Consulting' => '專業服務與諮詢',
    'industry_Real Estate' => '房地產',
    'industry_Restaurant & Catering' => '餐廳與餐飲業',
    'industry_Retail & Wholesale' => '批發零售',
    'industry_Sports' => '運動',
    'industry_Transportation' => '運輸',
    'industry_Travel & Luxury' => '旅遊與奢華',
    'industry_Other' => '其他',
    'industry_Photography' => '攝影',

    // Countries
    'country_Afghanistan' => '阿富汗',
    'country_Albania' => '阿爾巴尼亞',
    'country_Antarctica' => '南極洲',
    'country_Algeria' => '阿爾及利亞',
    'country_American Samoa' => '美屬薩摩亞',
    'country_Andorra' => '安道爾',
    'country_Angola' => '安哥拉',
    'country_Antigua and Barbuda' => '安地卡及巴布達',
    'country_Azerbaijan' => '亞塞拜然',
    'country_Argentina' => '阿根廷',
    'country_Australia' => '澳洲',
    'country_Austria' => '奧地利',
    'country_Bahamas' => '巴哈馬',
    'country_Bahrain' => '巴林',
    'country_Bangladesh' => '孟加拉',
    'country_Armenia' => '亞美尼亞',
    'country_Barbados' => '巴貝多',
    'country_Belgium' => '比利時',
    'country_Bermuda' => '百慕達',
    'country_Bhutan' => '不丹',
    'country_Bolivia, Plurinational State of' => '玻利維亞',
    'country_Bosnia and Herzegovina' => '波士尼亞與赫塞哥維納',
    'country_Botswana' => '波札那',
    'country_Bouvet Island' => '布威島',
    'country_Brazil' => '巴西',
    'country_Belize' => '貝里斯',
    'country_British Indian Ocean Territory' => '英屬印度洋領地',
    'country_Solomon Islands' => '所羅門群島',
    'country_Virgin Islands, British' => '英屬維京群島',
    'country_Brunei Darussalam' => '汶萊',
    'country_Bulgaria' => '保加利亞',
    'country_Myanmar' => '緬甸',
    'country_Burundi' => '蒲隆地',
    'country_Belarus' => '白俄羅斯',
    'country_Cambodia' => '柬埔寨',
    'country_Cameroon' => '喀麥隆',
    'country_Canada' => '加拿大',
    'country_Cape Verde' => '維德角',
    'country_Cayman Islands' => '開曼群島',
    'country_Central African Republic' => '中非共和國',
    'country_Sri Lanka' => '斯里蘭卡',
    'country_Chad' => '查德',
    'country_Chile' => '智利',
    'country_China' => '中國',
    'country_Taiwan, Province of China' => '台灣',
    'country_Christmas Island' => '聖誕島',
    'country_Cocos (Keeling) Islands' => '科科斯 (基林) 群島',
    'country_Colombia' => '哥倫比亞',
    'country_Comoros' => '葛摩',
    'country_Mayotte' => '馬約特',
    'country_Congo' => '剛果',
    'country_Congo, the Democratic Republic of the' => '剛果人民共和國',
    'country_Cook Islands' => '庫克群島',
    'country_Costa Rica' => '哥斯大黎加',
    'country_Croatia' => '克羅埃西亞',
    'country_Cuba' => '古巴',
    'country_Cyprus' => '塞浦路斯',
    'country_Czech Republic' => '捷克共和國',
    'country_Benin' => '貝南',
    'country_Denmark' => '丹麥',
    'country_Dominica' => '多米尼克',
    'country_Dominican Republic' => '多明尼加共和國',
    'country_Ecuador' => '厄瓜多',
    'country_El Salvador' => '薩爾瓦多',
    'country_Equatorial Guinea' => '赤道幾內亞',
    'country_Ethiopia' => '衣索比亞',
    'country_Eritrea' => '厄利垂亞',
    'country_Estonia' => '愛沙尼亞',
    'country_Faroe Islands' => '法羅島',
    'country_Falkland Islands (Malvinas)' => '福克蘭群島 (馬爾維納斯)',
    'country_South Georgia and the South Sandwich Islands' => '南喬治亞與南桑威奇',
    'country_Fiji' => '斐濟',
    'country_Finland' => '芬蘭',
    'country_Åland Islands' => '奧蘭群島',
    'country_France' => '法國',
    'country_French Guiana' => '法屬幾內亞',
    'country_French Polynesia' => '法屬玻里尼西亞',
    'country_French Southern Territories' => '法屬南方領地',
    'country_Djibouti' => '吉布地',
    'country_Gabon' => '加彭',
    'country_Georgia' => '喬治亞',
    'country_Gambia' => '甘比亞',
    'country_Palestinian Territory, Occupied' => '巴勒斯坦',
    'country_Germany' => '德國',
    'country_Ghana' => '迦納',
    'country_Gibraltar' => '直布羅陀',
    'country_Kiribati' => '吉里巴斯',
    'country_Greece' => '希臘',
    'country_Greenland' => '格陵蘭',
    'country_Grenada' => '格瑞那達',
    'country_Guadeloupe' => '瓜德羅普',
    'country_Guam' => '關島',
    'country_Guatemala' => '瓜地馬拉',
    'country_Guinea' => '幾內亞',
    'country_Guyana' => '圭亞那',
    'country_Haiti' => '海地',
    'country_Heard Island and McDonald Islands' => '赫德島和麥克唐納群島',
    'country_Holy See (Vatican City State)' => '聖座 (梵諦岡)',
    'country_Honduras' => '宏都拉斯',
    'country_Hong Kong' => '香港',
    'country_Hungary' => '匈牙利',
    'country_Iceland' => '冰島',
    'country_India' => '印度',
    'country_Indonesia' => '印尼',
    'country_Iran, Islamic Republic of' => '伊朗',
    'country_Iraq' => '伊拉克',
    'country_Ireland' => '愛爾蘭',
    'country_Israel' => '以色列',
    'country_Italy' => '義大利',
    'country_Côte d\'Ivoire' => '象牙海岸',
    'country_Jamaica' => '牙買加',
    'country_Japan' => '日本',
    'country_Kazakhstan' => '哈薩克',
    'country_Jordan' => '約旦',
    'country_Kenya' => '肯亞',
    'country_Korea, Democratic People\'s Republic of' => '北韓',
    'country_Korea, Republic of' => '南韓',
    'country_Kuwait' => '科威特',
    'country_Kyrgyzstan' => '吉爾吉斯',
    'country_Lao People\'s Democratic Republic' => '寮國',
    'country_Lebanon' => '黎巴嫩',
    'country_Lesotho' => '賴索托',
    'country_Latvia' => '拉脫維亞',
    'country_Liberia' => '賴比瑞亞',
    'country_Libya' => '利比亞',
    'country_Liechtenstein' => '列支敦士敦',
    'country_Lithuania' => '立陶宛',
    'country_Luxembourg' => '盧森堡',
    'country_Macao' => '澳門',
    'country_Madagascar' => '馬達加斯加',
    'country_Malawi' => '馬拉威',
    'country_Malaysia' => '馬來西亞',
    'country_Maldives' => '馬爾地夫',
    'country_Mali' => '馬利',
    'country_Malta' => '馬爾他',
    'country_Martinique' => '馬提尼克',
    'country_Mauritania' => '茅利塔尼亞',
    'country_Mauritius' => '模里西斯',
    'country_Mexico' => '墨西哥',
    'country_Monaco' => '摩納哥',
    'country_Mongolia' => '蒙古',
    'country_Moldova, Republic of' => '摩爾多瓦共和國',
    'country_Montenegro' => '蒙特內哥羅',
    'country_Montserrat' => '蒙特塞拉特',
    'country_Morocco' => '摩洛哥',
    'country_Mozambique' => '莫三比克',
    'country_Oman' => '阿曼',
    'country_Namibia' => '納比亞',
    'country_Nauru' => '諾魯',
    'country_Nepal' => '尼泊爾',
    'country_Netherlands' => '荷蘭',
    'country_Curaçao' => '古拉索',
    'country_Aruba' => '阿魯巴',
    'country_Sint Maarten (Dutch part)' => '聖馬丁 (荷屬部分)',
    'country_Bonaire, Sint Eustatius and Saba' => '波奈、聖佑達修斯及沙巴',
    'country_New Caledonia' => '新喀里多尼亞',
    'country_Vanuatu' => '萬那杜',
    'country_New Zealand' => '紐西蘭',
    'country_Nicaragua' => '尼加拉瓜',
    'country_Niger' => '尼日',
    'country_Nigeria' => '奈及利亞',
    'country_Niue' => '紐埃',
    'country_Norfolk Island' => '諾福克島',
    'country_Norway' => '挪威',
    'country_Northern Mariana Islands' => '北馬利納群島',
    'country_United States Minor Outlying Islands' => '美屬邊疆群島',
    'country_Micronesia, Federated States of' => '密克羅尼西亞邦聯',
    'country_Marshall Islands' => '馬紹爾群島',
    'country_Palau' => '帛琉',
    'country_Pakistan' => '巴基斯坦',
    'country_Panama' => '巴拿馬',
    'country_Papua New Guinea' => '巴布亞紐幾內亞',
    'country_Paraguay' => '巴拉圭',
    'country_Peru' => '秘魯',
    'country_Philippines' => '菲律賓',
    'country_Pitcairn' => '皮特凱恩',
    'country_Poland' => '波蘭',
    'country_Portugal' => '葡萄牙',
    'country_Guinea-Bissau' => '幾內亞比索',
    'country_Timor-Leste' => '東帝汶',
    'country_Puerto Rico' => '波多黎各',
    'country_Qatar' => '卡達',
    'country_Réunion' => '留尼旺',
    'country_Romania' => '羅馬尼亞',
    'country_Russian Federation' => '俄俄羅斯聯邦',
    'country_Rwanda' => '盧安達',
    'country_Saint Barthélemy' => '聖巴台勒密',
    'country_Saint Helena, Ascension and Tristan da Cunha' => '聖赫勒拿、亞森欣與垂斯坦昆哈',
    'country_Saint Kitts and Nevis' => '聖克里斯多福及尼維斯',
    'country_Anguilla' => '安圭拉',
    'country_Saint Lucia' => '聖露西亞',
    'country_Saint Martin (French part)' => '聖馬丁 (法屬部份)',
    'country_Saint Pierre and Miquelon' => '聖皮耶與密克隆',
    'country_Saint Vincent and the Grenadines' => '聖文森及格瑞那丁',
    'country_San Marino' => '聖馬利諾',
    'country_Sao Tome and Principe' => '聖多美普林西比',
    'country_Saudi Arabia' => '沙烏地阿拉伯',
    'country_Senegal' => '塞內加爾',
    'country_Serbia' => '塞爾維亞',
    'country_Seychelles' => '塞席爾',
    'country_Sierra Leone' => '獅子山',
    'country_Singapore' => '新加坡',
    'country_Slovakia' => '斯洛伐克',
    'country_Viet Nam' => '越南',
    'country_Slovenia' => '斯洛伐尼亞',
    'country_Somalia' => '索馬利亞',
    'country_South Africa' => '南非',
    'country_Zimbabwe' => '辛巴威',
    'country_Spain' => '西班牙',
    'country_South Sudan' => '南蘇丹',
    'country_Sudan' => '蘇丹',
    'country_Western Sahara' => '西撒哈拉',
    'country_Suriname' => '蘇利南',
    'country_Svalbard and Jan Mayen' => '斯瓦巴和揚馬延',
    'country_Swaziland' => '史瓦濟蘭',
    'country_Sweden' => '瑞典',
    'country_Switzerland' => '瑞士',
    'country_Syrian Arab Republic' => '敘利亞阿拉伯共和國',
    'country_Tajikistan' => '塔吉克',
    'country_Thailand' => '泰國',
    'country_Togo' => '多哥',
    'country_Tokelau' => '托克勞',
    'country_Tonga' => '東加',
    'country_Trinidad and Tobago' => '千里達及托巴哥',
    'country_United Arab Emirates' => '阿拉伯聯合大公國',
    'country_Tunisia' => '突尼西亞',
    'country_Turkey' => '土耳其',
    'country_Turkmenistan' => '土庫曼',
    'country_Turks and Caicos Islands' => '特克斯與開科斯群島',
    'country_Tuvalu' => '吐瓦魯',
    'country_Uganda' => '烏干達',
    'country_Ukraine' => '烏克蘭',
    'country_Macedonia, the former Yugoslav Republic of' => '馬其頓',
    'country_Egypt' => '埃及',
    'country_United Kingdom' => '聯合王國',
    'country_Guernsey' => '根息',
    'country_Jersey' => '澤西',
    'country_Isle of Man' => '曼島',
    'country_Tanzania, United Republic of' => '坦尚尼亞',
    'country_United States' => '美國',
    'country_Virgin Islands, U.S.' => '美屬維京群島',
    'country_Burkina Faso' => '布吉納法索',
    'country_Uruguay' => '烏拉圭',
    'country_Uzbekistan' => '烏茲別克',
    'country_Venezuela, Bolivarian Republic of' => '委內瑞拉',
    'country_Wallis and Futuna' => '瓦利斯和富圖納',
    'country_Samoa' => '薩摩亞',
    'country_Yemen' => '葉門',
    'country_Zambia' => '尚比亞',

    // Languages
    'lang_Brazilian Portuguese' => '巴西的葡萄牙文',
    'lang_Croatian' => '克羅埃西亞文',
    'lang_Czech' => '捷克文',
    'lang_Danish' => '丹麥文',
    'lang_Dutch' => '荷蘭文',
    'lang_English' => '英文',
    'lang_French' => '法文',
    'lang_French - Canada' => '法文 - 加拿大',
    'lang_German' => '德文',
    'lang_Italian' => '義大利文',
    'lang_Japanese' => '日文',
    'lang_Lithuanian' => '立陶宛文',
    'lang_Norwegian' => '挪威文',
    'lang_Polish' => '波蘭文',
    'lang_Spanish' => '西班牙文',
    'lang_Spanish - Spain' => '西班牙文 - 西班牙',
    'lang_Swedish' => '瑞典文',
    'lang_Albanian' => '阿爾巴尼亞文',
    'lang_Greek' => '希臘的',
    'lang_English - United Kingdom' => '英文 - 英國',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => '斯洛維尼亞文',
    'lang_Finnish' => '芬蘭文',
    'lang_Romanian' => '羅馬尼亞文',
    'lang_Turkish - Turkey' => '土耳其文 - 土耳其',
    'lang_Portuguese - Brazilian' => '葡萄牙文 - 巴西',
    'lang_Portuguese - Portugal' => '葡萄牙文 - 葡萄牙',
    'lang_Thai' => '泰文',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbian',
    'lang_Bulgarian' => 'Bulgarian',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => '會計與法務',
    'industry_Advertising' => '廣告',
    'industry_Aerospace' => '航太工業',
    'industry_Agriculture' => '農業',
    'industry_Automotive' => '汽車工業',
    'industry_Banking & Finance' => '銀行與保險',
    'industry_Biotechnology' => '生物科技',
    'industry_Broadcasting' => '傳播',
    'industry_Business Services' => '商業服務',
    'industry_Commodities & Chemicals' => '化學產品',
    'industry_Communications' => '通訊',
    'industry_Computers & Hightech' => '電腦與高科技',
    'industry_Defense' => '國防',
    'industry_Energy' => '能源',
    'industry_Entertainment' => '娛樂',
    'industry_Government' => '政府',
    'industry_Healthcare & Life Sciences' => '醫療保健與生命科學',
    'industry_Insurance' => '保險',
    'industry_Manufacturing' => '製造業',
    'industry_Marketing' => '行銷',
    'industry_Media' => '媒體',
    'industry_Nonprofit & Higher Ed' => '非營利與高等教育',
    'industry_Pharmaceuticals' => '藥品',
    'industry_Professional Services & Consulting' => '專業服務與諮詢',
    'industry_Real Estate' => '房地產',
    'industry_Retail & Wholesale' => '批發零售',
    'industry_Sports' => '運動',
    'industry_Transportation' => '運輸',
    'industry_Travel & Luxury' => '旅遊與奢華',
    'industry_Other' => '其他',
    'industry_Photography' => '攝影',

    'view_client_portal' => '檢視用戶入口頁面',
    'view_portal' => '檢視入口頁面',
    'vendor_contacts' => '供應商連絡人',
    'all' => '全部',
    'selected' => '已選的',
    'category' => '類別',
    'categories' => '類別',
    'new_expense_category' => '新的支出類別',
    'edit_category' => '編輯類別',
    'archive_expense_category' => '歸檔類別',
    'expense_categories' => '支出類別',
    'list_expense_categories' => '列出支出類別',
    'updated_expense_category' => '更新支出類別成功',
    'created_expense_category' => '成功建立支出類別',
    'archived_expense_category' => '歸檔支出類別成功',
    'archived_expense_categories' => '歸檔 :count 項支出類別成功',
    'restore_expense_category' => '復原支出類別',
    'restored_expense_category' => '復原支出類別成功',
    'apply_taxes' => '套用稅額',
    'min_to_max_users' => ':min 至 :max 名使用者',
    'max_users_reached' => '已達使用者人數上限。',
    'buy_now_buttons' => '現在即購買按鈕',
    'landing_page' => '入口網頁',
    'payment_type' => '付款方式',
    'form' => '表單',
    'link' => '連結',
    'fields' => '欄位',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => '注意: 即使交易記錄未完成，也會建立用戶和發票。',
    'buy_now_buttons_disabled' => '這項功能需先建立一項產品資料並設定一個付款閘道。',
    'enable_buy_now_buttons_help' => '啟用支援立即購買按鈕',
    'changes_take_effect_immediately' => '注意: 更改立即生效',
    'wepay_account_description' => '於 Invoice Ninja 使用的付款閘道',
    'payment_error_code' => '處理您的付款時發生錯誤 [:code]。請稍後再試。',
    'standard_fees_apply' => '費用: 2.9%/1.2% 〔信用卡/銀行轉帳〕+ $0.30 每次成功交易。',
    'limit_import_rows' => '需要批次匯入 :count 或較少行資料',
    'error_title' => '發生錯誤',
    'error_contact_text' => '若您願協助，請寫電子郵件給我們 :mailaddress',
    'no_undo' => '警告: 這無法復原。',
    'no_contact_selected' => '請選擇一種聯絡方式',
    'no_client_selected' => '請選取一個用戶',

    'gateway_config_error' => '重設密碼或產生一個新的 API 金鑰，可能會有用。',
    'payment_type_on_file' => ':type 在檔案',
    'invoice_for_client' => '給 :client 的發票 :invoice',
    'intent_not_found' => '抱歉，我不確定您問的是什麼。',
    'intent_not_supported' => '抱歉，我無法做那個。',
    'client_not_found' => '我未能找到用戶',
    'not_allowed' => '抱歉，您未經授權',
    'bot_emailed_invoice' => '您的發票已經傳送。',
    'bot_emailed_notify_viewed' => '我將查閱後以電子郵件寄給您。',
    'bot_emailed_notify_paid' => '我將在這筆款項支付後以電子郵件寄給您。',
    'add_product_to_invoice' => '新增 1 :product',
    'not_authorized' => '您未經授權',
    'bot_get_email' => '嗨! (wave)<br/>感謝您試用 Invoice Ninja 機器人。<br/>您需建立一個免費帳號以使用這個機器人。<br/>寄給我您的帳號所使用的電子郵件地址，以開始使用它。',
    'bot_get_code' => '感謝! 我已寄給您一封電子郵件，內有您的安全密碼。',
    'bot_welcome' => '好了，您的帳戶已經過驗證。<br/>',
    'email_not_found' => '我無法找到 :email 的可用帳戶',
    'invalid_code' => '密碼不正確',
    'security_code_email_subject' => 'Invoice Ninja 機器人的安全密碼',
    'security_code_email_line1' => '這是您的 Invoice Ninja 機器人安全密碼。',
    'security_code_email_line2' => '注意: 它將在 10 分鐘後失效。',
    'bot_help_message' => '我目前支援:<br/>â€¢ 建立\\更新\\透過電子郵件傳送票證<br/>â€¢ 列出產品<br/>例如:<br/><i>2 張票的發票，將到期日期設定為下週四，折扣定為 10%</i>',
    'list_products' => '將所有產品列表',

    'include_item_taxes_inline' => '包含 <b>單項產品稅金於該項目的總金額</b>',
    'created_quotes' => '建立 :count 份報價單成功',
    'limited_gateways' => '注意: 我們的政策是，每個公司僅使用一個信用卡付款閘道。',

    'warning' => '警告',
    'self-update' => '更新',
    'update_invoiceninja_title' => '更新 Invoice Ninja',
    'update_invoiceninja_warning' => '在開始更新 Invoice Ninja 之前，先備份您的資料庫與檔案!',
    'update_invoiceninja_available' => '有新版的 Invoice Ninja 可用。',
    'update_invoiceninja_unavailable' => 'Invoice Ninja 無更新的版本。',
    'update_invoiceninja_instructions' => '請點擊以下的<em>現在更新</em>按鈕以安裝新版本 <strong>:version</strong>。然後，您將會被轉引到總覽頁。',
    'update_invoiceninja_update_start' => '現在更新',
    'update_invoiceninja_download_start' => '下載 :version',
    'create_new' => '建立新的',

    'toggle_navigation' => '切換導覽',
    'toggle_history' => '切換歷程記錄',
    'unassigned' => '未分配的',
    'task' => '任務',
    'contact_name' => '聯絡人姓名',
    'city_state_postal' => '城市/州省/郵遞區號',
    'custom_field' => '自訂欄位',
    'account_fields' => '公司欄位',
    'facebook_and_twitter' => 'Facebook 和 Twitter',
    'facebook_and_twitter_help' => '訂閱我們的最新消息以協助支持我們的計畫',
    'reseller_text' => '注意: 白牌授權僅供個人使用；若您要轉售這個程式，請寫電子郵件給我們 :email。',
    'unnamed_client' => '未命名的用戶',

    'day' => '日',
    'week' => '星期',
    'month' => '月',
    'inactive_logout' => '您久未有動作，所以被登出',
    'reports' => '報告',
    'total_profit' => '獲利總計',
    'total_expenses' => '支出總計',
    'quote_to' => '報價單，開立給',

    // Limits
    'limit' => '限制',
    'min_limit' => '最小值: :min',
    'max_limit' => '最大值: :max',
    'no_limit' => '無限制',
    'set_limits' => '設定 :gateway_type 之限制',
    'enable_min' => '啟用最小值',
    'enable_max' => '啟用最大值',
    'min' => '最小值',
    'max' => '最大值',
    'limits_not_met' => '此發票不符合該付款類型的限制。',

    'date_range' => '日期範圍',
    'raw' => 'Raw',
    'raw_html' => 'Raw HTML',
    'update' => '更新',
    'invoice_fields_help' => '拖曳欄位以改變其順序與位置',
    'new_category' => '新類別',
    'restore_product' => '復原產品資料',
    'blank' => '空白',
    'invoice_save_error' => '儲存您的發票時出現錯誤',
    'enable_recurring' => '啟用週期性',
    'disable_recurring' => '停用週期性',
    'text' => '文字',
    'expense_will_create' => '將建立支出資料',
    'expenses_will_create' => '將建立支出資料',
    'created_expenses' => '建立 :count 項支出資料成功',

    'translate_app' => '透過 :link 協助改善我們的翻譯',
    'expense_category' => '支出類別',

    'go_ninja_pro' => '前往 Ninja 專業版!',
    'go_enterprise' => '前往企業版!',
    'upgrade_for_features' => '升級以使用更多功能',
    'pay_annually_discount' => '年繳 10 個月的月費，即享有 2 個月免費!',
    'pro_upgrade_title' => 'Ninja 專業版',
    'pro_upgrade_feature1' => '您的品牌.InvoiceNinja.com',
    'pro_upgrade_feature2' => '在各方面自訂您的發票!',
    'enterprise_upgrade_feature1' => '設定多使用者的權限',
    'enterprise_upgrade_feature2' => '將第 3 方的檔案附加於發票與支出資料',
    'much_more' => '還有更多!',
    'all_pro_fetaures' => '加上所有的專業版功能!',

    'currency_symbol' => '符號',
    'currency_code' => '代碼',

    'buy_license' => '購買授權',
    'apply_license' => '套用授權',
    'submit' => '提交',
    'white_label_license_key' => '授權金鑰',
    'invalid_white_label_license' => '白牌授權無效',
    'created_by' => '由 :name 建立',
    'modules' => '模組',
    'financial_year_start' => '年度的第一個月',
    'authentication' => '驗證',
    'checkbox' => '核選方塊',
    'invoice_signature' => '簽名',
    'show_accept_invoice_terms' => '發票條款核取方塊',
    'show_accept_invoice_terms_help' => '要求用戶確認他們接受發票條款。',
    'show_accept_quote_terms' => '報價單條款核取方塊',
    'show_accept_quote_terms_help' => '要求用戶確認他們接受報價條款。',
    'require_invoice_signature' => '發票簽名',
    'require_invoice_signature_help' => '要求用戶提供其簽名。',
    'require_quote_signature' => '報價單簽名',
    'require_quote_signature_help' => '要求用戶提供其簽名。',
    'i_agree' => '我同意這些條款',
    'sign_here' => '請在此處簽名:',
    'authorization' => '授權',
    'signed' => '已簽署',

    // BlueVine
    'bluevine_promo' => '使用 BlueVine，以彈性的商營運方式進行貸款與發票結帳。',
    'bluevine_modal_label' => '透過 BlueVine 登入',
    'bluevine_modal_text' => '<h3>快速建立您的企業。無紙化。</h3>
<ul><li>以彈性的商營運方式進行貸款與發票結帳。</li></ul>',
    'bluevine_create_account' => '建立一個帳號',
    'quote_types' => '取得報價單',
    'invoice_factoring' => '開立應收帳款承購的發票',
    'line_of_credit' => '貸款額度',
    'fico_score' => '您的 FICO 分數',
    'business_inception' => '營運起始日',
    'average_bank_balance' => '平均銀行帳戶餘額',
    'annual_revenue' => '年收入',
    'desired_credit_limit_factoring' => '希望設定的發票貼現限額',
    'desired_credit_limit_loc' => '希望的貸款限額基準線',
    'desired_credit_limit' => '希望的貸款額度',
    'bluevine_credit_line_type_required' => '您必須至少選擇一項',
    'bluevine_field_required' => '此欄位為必填',
    'bluevine_unexpected_error' => '發生未預期的錯誤。',
    'bluevine_no_conditional_offer' => '取得報價單之前，需提供更多資訊。點擊以下繼續。',
    'bluevine_invoice_factoring' => '開立應收帳款承購的發票',
    'bluevine_conditional_offer' => '附條件報價',
    'bluevine_credit_line_amount' => '貸款額度',
    'bluevine_advance_rate' => '預付率',
    'bluevine_weekly_discount_rate' => '每週折扣率',
    'bluevine_minimum_fee_rate' => '最低費用',
    'bluevine_line_of_credit' => '信用額度',
    'bluevine_interest_rate' => '利率',
    'bluevine_weekly_draw_rate' => '每週支取率',
    'bluevine_continue' => '前往 BlueVine',
    'bluevine_completed' => '已完成註冊 BlueVine',

    'vendor_name' => '供應商',
    'entity_state' => '狀態',
    'client_created_at' => '建立日期',
    'postmark_error' => '透過 Postmark: :link 傳送電子郵件時發生問題',
    'project' => '專案',
    'projects' => '專案',
    'new_project' => '新專案',
    'edit_project' => '編輯專案',
    'archive_project' => '歸檔專案',
    'list_projects' => '列出各項專案',
    'updated_project' => '成功更新的專案',
    'created_project' => '建立專案成功',
    'archived_project' => '歸檔專案項目成功',
    'archived_projects' => '歸檔 :count 項專案成功',
    'restore_project' => '復原之專案',
    'restored_project' => '復原專案成功',
    'delete_project' => '刪除專案',
    'deleted_project' => 'Successfully deleted project',
    'deleted_projects' => '刪除 :count 件專案成功',
    'delete_expense_category' => '刪除類別',
    'deleted_expense_category' => '刪除類別成功',
    'delete_product' => '刪除貸款資料',
    'deleted_product' => '已成功刪除產品資料',
    'deleted_products' => '刪除 :count 筆產品資料成功',
    'restored_product' => '復原產品資料成功',
    'update_credit' => '更新貸款資料',
    'updated_credit' => '更新貸款資料成功',
    'edit_credit' => '編輯貸款資料',
    'realtime_preview' => 'Realtime Preview',
    'realtime_preview_help' => 'Realtime refresh PDF preview on the invoice page when editing invoice.<br/>Disable this to improve performance when editing invoices.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.',
    'force_pdfjs_help' => '在 :chrome_link 與 :firefox_link 中取代 PDF 閱讀器。<br/>如果您的瀏覽器會自動下載 PDF，啟用此選項。',
    'force_pdfjs' => '防止下載',
    'redirect_url' => '重新導向 URL',
    'redirect_url_help' => '可選擇性地指定一個在付款完成後進行重新導向的網址。',
    'save_draft' => '儲存草稿',
    'refunded_credit_payment' => '已退款之貸款支付',
    'keyboard_shortcuts' => '鍵盤快速鍵',
    'toggle_menu' => '切換選單',
    'new_...' => '新增 ...',
    'list_...' => '清單 ...',
    'created_at' => '建立日期',
    'contact_us' => '聯絡我們',
    'user_guide' => '使用者指南',
    'promo_message' => '在 :expires 之前升級，並獲得您第一年訂用我們的專業版或企業版的折價 :amount 。',
    'discount_message' => '在 :expires 之前減價 :amount',
    'mark_paid' => '標記已付',
    'marked_sent_invoice' => '標記發票為已傳送成功',
    'marked_sent_invoices' => '標記發票為已傳送成功',
    'invoice_name' => '發票',
    'product_will_create' => '將會建立產品',
    'contact_us_response' => '感謝您的來信! 我們會儘速回覆。',
    'last_7_days' => '最近 7 天',
    'last_30_days' => '最近 30 天',
    'this_month' => '本月',
    'last_month' => '上個月',
    'current_quarter' => 'Current Quarter',
    'last_quarter' => 'Last Quarter',
    'last_year' => '下個月',
    'custom_range' => '自訂範圍',
    'url' => 'URL',
    'debug' => '偵錯',
    'https' => 'HTTPS',
    'require' => '要求',
    'license_expiring' => '注意事項: 您的授權將在 :count 日到期，請至 :link 進行更新。',
    'security_confirmation' => '您的電子郵件地址已確認。',
    'white_label_expired' => '您的白牌授權已過期，請考慮續約以協助支持我們的計劃。',
    'renew_license' => '更新授權',
    'iphone_app_message' => '不妨考慮下載我們的 :link',
    'iphone_app' => 'iPhone App',
    'android_app' => 'Android App',
    'logged_in' => '已登入',
    'switch_to_primary' => '切換至您的主要公司 (:name) 以管理您的方案。',
    'inclusive' => '內含',
    'exclusive' => '不含',
    'postal_city_state' => '城市/州省/郵遞區號',
    'phantomjs_help' => '在某些情況下，此程式使用 :link_phantom 來產生 PDF 檔案，請安裝 :link_docs 以在本機產生。',
    'phantomjs_local' => '使用本機的 PhantomJS',
    'client_number' => '用戶編號',
    'client_number_help' => '指定字首或使用自訂樣式動態設定用戶編號。',
    'next_client_number' => '下一個用戶編號為 :number。',
    'generated_numbers' => '自動產生之號碼',
    'notes_reminder1' => '首次提醒',
    'notes_reminder2' => '第二次提醒',
    'notes_reminder3' => '第三次提醒',
    'notes_reminder4' => 'Reminder',
    'bcc_email' => '電子郵件密件副本',
    'tax_quote' => '稅額報價',
    'tax_invoice' => '稅金發票',
    'emailed_invoices' => '以電子郵件寄出發票成功',
    'emailed_quotes' => '以電子郵件寄出報價單成功',
    'website_url' => '網站網址',
    'domain' => '網域',
    'domain_help' => '在用戶門戶頁面和傳送電子郵件時使用。',
    'domain_help_website' => '用於寄送電子郵件時。',
    'import_invoices' => '匯入發票',
    'new_report' => '新報告',
    'edit_report' => '編輯報告',
    'columns' => '欄',
    'filters' => '篩選器',
    'sort_by' => '排序依據',
    'draft' => '草稿',
    'unpaid' => '未付款',
    'aging' => '帳齡',
    'age' => '年齡',
    'days' => '日',
    'age_group_0' => '0 - 30 天',
    'age_group_30' => '30 - 60 天',
    'age_group_60' => '60 - 90 天',
    'age_group_90' => '90 - 120 天',
    'age_group_120' => '120 天以上',
    'invoice_details' => '發票詳細內容',
    'qty' => '數量',
    'profit_and_loss' => '利潤與損失',
    'revenue' => '收入',
    'profit' => '利潤',
    'group_when_sorted' => '群組排序',
    'group_dates_by' => '分組日期依據',
    'year' => '年',
    'view_statement' => '檢視財務報表',
    'statement' => '財務報表',
    'statement_date' => '財務報表日期',
    'mark_active' => '標記使用中',
    'send_automatically' => '自動寄送',
    'initial_email' => '最初的電子郵件',
    'invoice_not_emailed' => '此發票未寄出。',
    'quote_not_emailed' => '此報價單未寄出。',
    'sent_by' => '由 :user 寄出',
    'recipients' => '收件人',
    'save_as_default' => '儲存為預設值',
    'start_of_week_help' => '由 <b>日期</b> 選擇器使用',
    'financial_year_start_help' => '由 <b>日期範圍</b> 選擇器使用',
    'reports_help' => 'Shift + Click 可多欄排序，Ctrl + Click 以取消組合。',
    'this_year' => '今年',

    // Updated login screen
    'ninja_tagline' => '建立、寄送、接受付款。',
    'login_or_existing' => '或使用已連結的帳號登入。',
    'sign_up_now' => '立即登入',
    'not_a_member_yet' => '尚未成為會員?',
    'login_create_an_account' => '建立一個帳號!',

    // New Client Portal styling
    'invoice_from' => '發票來自:',
    'email_alias_message' => '我們要求每個公司擁有專屬的電子郵件地址。<br/>建議使用代稱。例如， email+label@example.com',
    'full_name' => '全名',
    'month_year' => '月/年',
    'valid_thru' => '瓦利德恩特魯魯',

    'product_fields' => '產品欄位',
    'custom_product_fields_help' => '在建立產品資料或發票時增加欄位，並在PDF檔案顯示其標題與值。',
    'freq_two_months' => '兩個月',
    'freq_yearly' => 'Annually',
    'profile' => '簡介',
    'payment_type_help' => '設定預設的<b>人工付款方式</b>。',
    'industry_Construction' => '建構',
    'your_statement' => '您的報表',
    'statement_issued_to' => '列出報表給',
    'statement_to' => '報表給',
    'customize_options' => '自訂選項',
    'created_payment_term' => '建立付款條款成功',
    'updated_payment_term' => '更新付款條款成功',
    'archived_payment_term' => '歸檔付款條款成功',
    'resend_invite' => '重寄邀請函',
    'credit_created_by' => '由 :transaction_reference付款所建立的貸款',
    'created_payment_and_credit' => '已成功建立付款與貸款資料',
    'created_payment_and_credit_emailed_client' => '成功建立付款和貸款，並透過電子郵件傳送給用戶',
    'create_project' => '建立專案',
    'create_vendor' => '建立供應商',
    'create_expense_category' => '建立類別',
    'pro_plan_reports' => ':link 來加入專業版，以啟用報告功能',
    'mark_ready' => '標記就緒',

    'limits' => '限制',
    'fees' => '費用',
    'fee' => '費用',
    'set_limits_fees' => '設定 :gateway_type 限制/費用',
    'fees_tax_help' => '啟用單列品項稅以設定費用稅率。',
    'fees_sample' => ':amount 份發票的費用應為 :total。',
    'discount_sample' => ':amount 的發票折價應為 :total。',
    'no_fees' => '無費用',
    'gateway_fees_disclaimer' => '警告: 不是每個國家/付款閘道都允許增加費用，請參考當地法律/服務條款。',
    'percent' => '百分比',
    'location' => '地點',
    'line_item' => '單列品項',
    'surcharge' => '額外費用',
    'location_first_surcharge' => '啟用 - 第一項額外費用',
    'location_second_surcharge' => '啟用 - 第二項額外費用',
    'location_line_item' => '啟用 - 單列品項',
    'online_payment_surcharge' => '線上付款額外費用',
    'gateway_fees' => '閘道費用',
    'fees_disabled' => '費用選項已停用',
    'gateway_fees_help' => '自動增加一項線上支付的額外費用/折扣。',
    'gateway' => '閘道',
    'gateway_fee_change_warning' => '若有未付的附加費用發票，這些發票需以人工方式進行更新。',
    'fees_surcharge_help' => '自訂附加費 :link。',
    'label_and_taxes' => '標籤與稅金',
    'billable' => '可結帳的',
    'logo_warning_too_large' => '這個圖片檔案太大。',
    'logo_warning_fileinfo' => '警告: 要支援 gifs 需要啟用檔案資訊 PHP 擴充功能。',
    'logo_warning_invalid' => '讀取圖片時發生問題，請試用另一種格式。',

    'error_refresh_page' => '發生錯誤，請重新載入網頁，然後再試一次。',
    'data' => '資料',
    'imported_settings' => '匯入設定值成功',
    'reset_counter' => '重設計數器',
    'next_reset' => '下一次重設',
    'reset_counter_help' => '自動地重設發票與報價單計數器。',
    'auto_bill_failed' => '發票:invoice_number之自動結帳失敗',
    'online_payment_discount' => '線上付款折扣',
    'created_new_company' => '已',
    'fees_disabled_for_gateway' => '費用資料功能在此閘道停用。',
    'logout_and_delete' => '登出/刪除帳號',
    'tax_rate_type_help' => '選取專用稅率時調整行項目成本。<br/>只有專用稅率可以用作預設值。',
    'invoice_footer_help' => '使用 $pageNumber 與 $pageCount 顯示頁面資訊。',
    'credit_note' => '貸款註記',
    'credit_issued_to' => '放款給',
    'credit_to' => '貸款給',
    'your_credit' => '您的貸款',
    'credit_number' => '貸款編號',
    'create_credit_note' => '建立貸款註記',
    'menu' => '選單',
    'error_incorrect_gateway_ids' => '錯誤: 閘道表有錯誤的帳號名稱。',
    'purge_data' => '清除資料',
    'delete_data' => '刪除資料',
    'purge_data_help' => '永久性地刪除所有資料，但保留帳號與設定。',
    'cancel_account_help' => '永久性地刪除帳號，以及所有資料與設定。',
    'purge_successful' => '清除公司資料成功',
    'forbidden' => '禁止的',
    'purge_data_message' => '警告: 這將永久性地抹除您的資料；沒有恢復的可能。',
    'contact_phone' => '聯絡人電話',
    'contact_email' => '聯絡人電子郵件',
    'reply_to_email' => '回覆電子郵件',
    'reply_to_email_help' => '指定用戶電子郵件的回覆位址。',
    'bcc_email_help' => '私人包括此位址與用戶電子郵件。',
    'import_complete' => '您的匯入已順利完成。',
    'confirm_account_to_import' => '請確認您的帳號以匯入資料。',
    'import_started' => '您的匯入已開始，我們將在匯入完畢後寄送一封電子郵件給您。',
    'listening' => '接聽中…',
    'microphone_help' => '說「[用戶] 的新發票」或「顯示我 [用戶] 的歸檔付款資料」',
    'voice_commands' => '聲控',
    'sample_commands' => '示範指令',
    'voice_commands_feedback' => '我們正積極致力於改善此功能。若有您希望我們支援的指令，請以電子郵件告訴我們 :email。',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => '匯票',
    'archived_products' => '歸檔 :count 項產品資料成功',
    'recommend_on' => '我們建議 <b>啟用</b> 這項設定。',
    'recommend_off' => '我們建議 <b>停用</b> 這項設定。',
    'notes_auto_billed' => '自動收款',
    'surcharge_label' => '額外費用標籤',
    'contact_fields' => '聯絡人欄位',
    'custom_contact_fields_help' => '於建立聯絡人資料時增加欄位，且可選擇在 PDF 檔案顯示欄位名稱與值。',
    'datatable_info' => '顯示 :total 個項目的 :start 至 :end 項',
    'credit_total' => '貸款總額',
    'mark_billable' => '標記計費',
    'billed' => '已開立帳單',
    'company_variables' => '公司變項',
    'client_variables' => '用戶變數',
    'invoice_variables' => '發票變數',
    'navigation_variables' => '導覽變數',
    'custom_variables' => '客戶變項',
    'invalid_file' => '無效的檔案類型',
    'add_documents_to_invoice' => '新增文件至發票',
    'mark_expense_paid' => '標記已付',
    'white_label_license_error' => '無法驗證授權。預知詳情，請檢查 storage/logs/laravel-error.log。',
    'plan_price' => '方案價格',
    'wrong_confirmation' => '不正確的認證碼',
    'oauth_taken' => '這個帳號已被登記',
    'emailed_payment' => '以電子郵件寄出付款成功',
    'email_payment' => '以電子郵件傳送付款資料',
    'invoiceplane_import' => '使用 :link 以從 InvoicePlan 移轉您的資料。',
    'duplicate_expense_warning' => '警告: 這個 :link 可能是重複的',
    'expense_link' => 'expense',
    'resume_task' => '繼續任務',
    'resumed_task' => '復原任務成功',
    'quote_design' => '報價單設計',
    'default_design' => '標準設計',
    'custom_design1' => '自訂設計 1',
    'custom_design2' => '自訂設計 2',
    'custom_design3' => '自訂設計 3',
    'empty' => '空',
    'load_design' => '載入設計',
    'accepted_card_logos' => '接受的卡片標誌',
    'phantomjs_local_and_cloud' => '使用本機的 PhantomJS，回到 phantomjscloud.com',
    'google_analytics' => 'Googlezp 分析',
    'analytics_key' => 'Analytics 金鑰',
    'analytics_key_help' => '使用 :link來追蹤付款',
    'start_date_required' => '起始日期為必填',
    'application_settings' => '應用程式設定',
    'database_connection' => '資料庫連線',
    'driver' => '磁碟',
    'host' => '主機',
    'database' => '資料庫',
    'test_connection' => '測試連線',
    'from_name' => '按照姓名',
    'from_address' => '按照地址',
    'port' => '埠',
    'encryption' => '加密',
    'mailgun_domain' => 'Mailgun 網域',
    'mailgun_private_key' => 'Mailgun 私密金鑰',
    'send_test_email' => '寄送測試郵件',
    'select_label' => '選擇標籤',
    'label' => '標籤',
    'service' => '服務',
    'update_payment_details' => '更新付款詳細資料',
    'updated_payment_details' => '更新付款詳細資料成功',
    'update_credit_card' => '更新信用卡',
    'recurring_expenses' => '週期性支出',
    'recurring_expense' => '週期性支出',
    'new_recurring_expense' => '新的週期性支出',
    'edit_recurring_expense' => '編輯週期性支出',
    'archive_recurring_expense' => '歸檔週期性支出',
    'list_recurring_expense' => '列出週期性支出',
    'updated_recurring_expense' => '更新週期性支出成功',
    'created_recurring_expense' => '建立週期性支出成功',
    'archived_recurring_expense' => '歸檔週期性支出成功',
    'restore_recurring_expense' => '復原週期性支出',
    'restored_recurring_expense' => '復原週期性支出成功',
    'delete_recurring_expense' => '刪除週期性支出',
    'deleted_recurring_expense' => 'Successfully deleted project',
    'view_recurring_expense' => '檢視週期性支出',
    'taxes_and_fees' => '稅金與費用',
    'import_failed' => '匯入失敗',
    'recurring_prefix' => '用以標示週期性的前置符號',
    'options' => '選項',
    'credit_number_help' => '設定一個前置符號或使用自訂型態，以動態地為欠款發票設定貸款號碼。',
    'next_credit_number' => '下一個貸款號碼是 :number。',
    'padding_help' => '補齊數字所使用的零的個數。',
    'import_warning_invalid_date' => '警告: 日期格式顯然無效。',
    'product_notes' => '產品註記',
    'app_version' => 'App 版本',
    'ofx_version' => 'OFX 版本',
    'gateway_help_23' => ':link 以取得您的 Stripe API 金鑰。',
    'error_app_key_set_to_default' => '錯誤:  APP_KEY 被設為預設值；先備份您的資料庫，然後執行 <code>php artisan ninja:update-key</code> 以更新之',
    'charge_late_fee' => '收取逾期費用',
    'late_fee_amount' => '逾期費用金額',
    'late_fee_percent' => '逾期費用率',
    'late_fee_added' => '增列逾期費用 :date',
    'download_invoice' => '下載發票',
    'download_quote' => '下載報價單',
    'invoices_are_attached' => '您的發票 PDF 檔案已附加到郵件。',
    'downloaded_invoice' => '將會寄出一封附有發票的 PDF 檔案之電子郵件',
    'downloaded_quote' => '將會寄出一封附有發票的 PDF 檔案之報價單',
    'downloaded_invoices' => '將會寄出一封附有發票的 PDF 檔案之電子郵件',
    'downloaded_quotes' => '將會寄出一封附有發票的 PDF 檔案之報價單',
    'clone_expense' => '再製',
    'default_documents' => '預設的文件',
    'send_email_to_client' => '向用戶傳送電子郵件',
    'refund_subject' => '已辦理退款',
    'refund_body' => '您的發票 :invoice_number 之 :amount 退款已辦理。',

    'currency_us_dollar' => '美元',
    'currency_british_pound' => '英鎊',
    'currency_euro' => '歐元',
    'currency_south_african_rand' => '南非蘭特',
    'currency_danish_krone' => '丹麥克朗',
    'currency_israeli_shekel' => '以色列謝克爾',
    'currency_swedish_krona' => '瑞典克朗',
    'currency_kenyan_shilling' => '肯亞先令',
    'currency_canadian_dollar' => '加拿大元',
    'currency_philippine_peso' => '菲律賓披索',
    'currency_indian_rupee' => '印度盧布',
    'currency_australian_dollar' => '澳幣',
    'currency_singapore_dollar' => '新加坡幣',
    'currency_norske_kroner' => '挪威克朗',
    'currency_new_zealand_dollar' => '紐西蘭幣',
    'currency_vietnamese_dong' => '越南盾',
    'currency_swiss_franc' => '瑞士法郎',
    'currency_guatemalan_quetzal' => '瓜地馬拉格查爾',
    'currency_malaysian_ringgit' => '馬來西亞令吉',
    'currency_brazilian_real' => '巴西里爾',
    'currency_thai_baht' => '泰銖',
    'currency_nigerian_naira' => '奈及利亞奈拉',
    'currency_argentine_peso' => '阿根廷披索',
    'currency_bangladeshi_taka' => '孟加拉塔卡',
    'currency_united_arab_emirates_dirham' => '阿拉伯聯合大公國幣',
    'currency_hong_kong_dollar' => '港幣',
    'currency_indonesian_rupiah' => '印尼盾',
    'currency_mexican_peso' => '墨西哥披索',
    'currency_egyptian_pound' => '埃及鎊',
    'currency_colombian_peso' => '哥倫比亞披索',
    'currency_west_african_franc' => '西非法郎',
    'currency_chinese_renminbi' => '中國人民幣',
    'currency_rwandan_franc' => '盧安達法郎',
    'currency_tanzanian_shilling' => '坦尚尼亞先令',
    'currency_netherlands_antillean_guilder' => '荷屬安地列斯盾',
    'currency_trinidad_and_tobago_dollar' => '特立尼達和多巴哥元',
    'currency_east_caribbean_dollar' => '東加勒比元',
    'currency_ghanaian_cedi' => '迦納塞地',
    'currency_bulgarian_lev' => '保加利亞列弗',
    'currency_aruban_florin' => '阿魯巴弗羅林',
    'currency_turkish_lira' => '土耳其里拉',
    'currency_romanian_new_leu' => '羅馬尼亞新列伊',
    'currency_croatian_kuna' => '克羅埃西亞庫納',
    'currency_saudi_riyal' => '沙烏地里亞爾',
    'currency_japanese_yen' => '日圓',
    'currency_maldivian_rufiyaa' => '馬爾地夫拉菲亞',
    'currency_costa_rican_colon' => '哥斯大黎加幣',
    'currency_pakistani_rupee' => '巴基斯坦盧比',
    'currency_polish_zloty' => '波蘭幣',
    'currency_sri_lankan_rupee' => '斯里蘭卡盧比',
    'currency_czech_koruna' => '捷克幣',
    'currency_uruguayan_peso' => '烏拉圭披索',
    'currency_namibian_dollar' => '納比亞元',
    'currency_tunisian_dinar' => '突尼西亞幣',
    'currency_russian_ruble' => '俄國盧布',
    'currency_mozambican_metical' => '莫三比克幣',
    'currency_omani_rial' => '阿曼里亞爾',
    'currency_ukrainian_hryvnia' => '烏克蘭格里夫納',
    'currency_macanese_pataca' => '澳門幣',
    'currency_taiwan_new_dollar' => '新台幣',
    'currency_dominican_peso' => '多明尼加披索',
    'currency_chilean_peso' => '智利披索',
    'currency_icelandic_krona' => '冰島克朗',
    'currency_papua_new_guinean_kina' => '巴布亞紐幾內亞基那',
    'currency_jordanian_dinar' => '約旦第納爾',
    'currency_myanmar_kyat' => '緬元',
    'currency_peruvian_sol' => '秘魯索爾',
    'currency_botswana_pula' => '波札那普拉',
    'currency_hungarian_forint' => '匈牙利幣',
    'currency_ugandan_shilling' => '烏干達仙令',
    'currency_barbadian_dollar' => '巴貝多元',
    'currency_brunei_dollar' => '汶萊元',
    'currency_georgian_lari' => '喬治亞幣',
    'currency_qatari_riyal' => '卡達幣',
    'currency_honduran_lempira' => '宏都拉斯倫皮拉',
    'currency_surinamese_dollar' => '蘇利南元',
    'currency_bahraini_dinar' => '巴林第納爾',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => '我們希望您喜歡使用這個程式。<br/>若您考慮 :link，我們會非常感謝!',
    'writing_a_review' => '撰寫評語',

    'use_english_version' => '確認使用這些檔案的英文版。<br/>我們使用欄標頭以配合欄位。',
    'tax1' => '首項稅負',
    'tax2' => '次項稅負',
    'fee_help' => '閘道費是使用處理線上支付的金融網路收取的費用。',
    'format_export' => '匯出格式',
    'custom1' => '首位顧客',
    'custom2' => '第二名顧客',
    'contact_first_name' => '聯絡人名字',
    'contact_last_name' => '聯絡人姓氏',
    'contact_custom1' => '聯絡人首位顧客',
    'contact_custom2' => '聯絡人第二位顧客',
    'currency' => '貨幣',
    'ofx_help' => '欲排除障礙，查閱 :ofxhome_link 的留言並以 :ofxget_link 進行測試。',
    'comments' => 'comments',

    'item_product' => '項目產品',
    'item_notes' => '項目註記',
    'item_cost' => '項目成本',
    'item_quantity' => '項目數量',
    'item_tax_rate' => '項目稅率',
    'item_tax_name' => '項目稅名',
    'item_tax1' => '項目稅 1',
    'item_tax2' => '項目稅 2',

    'delete_company' => '刪除公司資料',
    'delete_company_help' => '永久刪除此公司及相關的所有資料與設定。',
    'delete_company_message' => '警告: 這將永久刪除您的公司資料，而且不可能復原。',

    'applied_discount' => '已使用折價券，所選擇的版本價格已減少 :discount%。',
    'applied_free_year' => '已使用折價券，您的帳戶已升級至專業版，有效期一年。',

    'contact_us_help' => '若您正在通報錯誤，請包含 storage/logs/laravel-error.log 之中的每個相關的記錄檔',
    'include_errors' => '包含錯誤',
    'include_errors_help' => '包含來自 storage/logs/laravel-error.log 的 :link',
    'recent_errors' => '最近的錯誤',
    'customer' => '顧客',
    'customers' => '顧客',
    'created_customer' => '已成功建立客戶資料',
    'created_customers' => '已成功建立 :count筆客戶資料',

    'purge_details' => '已成功地清除您的公司 (:account) 資料。',
    'deleted_company' => '刪除公司資料成功',
    'deleted_account' => '取消帳戶成功',
    'deleted_company_details' => '已成功地刪除您的公司 (:account) 資料。',
    'deleted_account_details' => '已成功地刪除您的帳戶 (:account) 資料。',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => '接受 Alipay',
    'enable_sofort' => '接受歐盟銀行轉帳',
    'stripe_alipay_help' => '這些閘道也需要以 :link 開通。',
    'calendar' => '日曆',
    'pro_plan_calendar' => ':link 來加入專業版，以啟用啟用日曆',

    'what_are_you_working_on' => '您目前從事什麼?',
    'time_tracker' => '時間追蹤器',
    'refresh' => '更新',
    'filter_sort' => '篩選/排序',
    'no_description' => '沒有描述',
    'time_tracker_login' => '登入時間追蹤',
    'save_or_discard' => '儲存或放棄您所做的變更',
    'discard_changes' => '放棄變更',
    'tasks_not_enabled' => '任務未啟用。',
    'started_task' => '展開任務成功',
    'create_client' => '建立用戶',

    'download_desktop_app' => '下載桌面 APP',
    'download_iphone_app' => '下載 iPhone APP',
    'download_android_app' => '下載 Android APP',
    'time_tracker_mobile_help' => '點擊兩次任務，以選取之',
    'stopped' => '停止的',
    'ascending' => '遞增',
    'descending' => '遞減',
    'sort_field' => '排序依據',
    'sort_direction' => '方向',
    'discard' => '放棄',
    'time_am' => '上午',
    'time_pm' => '下午',
    'time_mins' => '分',
    'time_hr' => '小時',
    'time_hrs' => '小時',
    'clear' => '清除',
    'warn_payment_gateway' => '注意: 接受使用線上支付需要一個付款閘道， :link 新增一個。',
    'task_rate' => '任務費率',
    'task_rate_help' => '為開立發票的任務設定預設費率。',
    'past_due' => '過去到期',
    'document' => '文件',
    'invoice_or_expense' => '發票/支出',
    'invoice_pdfs' => '發票的 PDF 檔案',
    'enable_sepa' => '接受 SEPA',
    'enable_bitcoin' => '接受比特幣',
    'iban' => '國際銀行帳戶號碼',
    'sepa_authorization' => '通過提供您的 IBAN 並確認此付款, 您授權: 我們的付款服務提供者公司和 Stripe 向您的銀行發送指令，以借記您的帳戶，並授權您的銀行按照這些指示借記您的帳戶。 根據您與銀行達成的協議的條款及條件，您有權從您的銀行獲得退款。 退款必須在您的帳戶被借記之日起的 8 周內提出。',
    'recover_license' => '收回授權',
    'purchase' => '購買',
    'recover' => '收回',
    'apply' => '套用',
    'recover_white_label_header' => '恢復白牌授權',
    'apply_white_label_header' => '套用白牌授權',
    'videos' => '影片',
    'video' => '影片',
    'return_to_invoice' => '返回「發票」',
    'gateway_help_13' => '若要使用 ITN，則讓 PDT 金鑰欄位留白。',
    'partial_due_date' => '部分截止日期',
    'task_fields' => '任務欄位',
    'product_fields_help' => '拖放欄位以來改變其順序',
    'custom_value1' => '自訂值',
    'custom_value2' => '自訂值',
    'enable_two_factor' => '兩步驟驗證',
    'enable_two_factor_help' => '在登入時使用您的手機來確認您的身份',
    'two_factor_setup' => '兩步驟驗證設定',
    'two_factor_setup_help' => '使用 :link 相容的 App 掃描條碼。',
    'one_time_password' => '一次性密碼',
    'set_phone_for_two_factor' => '設定您的手機號碼，以作為備用的啟用方式。',
    'enabled_two_factor' => '啟用兩步驟驗證成功',
    'add_product' => '加入產品',
    'email_will_be_sent_on' => '注意: 電子郵件將於 :date 寄出。',
    'invoice_product' => '為產品開立發票',
    'self_host_login' => '自設網站之登入',
    'set_self_hoat_url' => '自設網站之網址',
    'local_storage_required' => '錯誤: 沒有本地端的資料儲存。',
    'your_password_reset_link' => '您的重設密碼連結',
    'subdomain_taken' => '這個子網域已使用',
    'client_login' => '用戶登入',
    'converted_amount' => '轉換的金額',
    'default' => '預設',
    'shipping_address' => '送貨位址',
    'bllling_address' => '帳單地址',
    'billing_address1' => '帳單地址之街/路',
    'billing_address2' => '帳單地址之大樓/套房',
    'billing_city' => '帳單地址之城市',
    'billing_state' => '帳單地址之州/省',
    'billing_postal_code' => '帳單地址之郵遞區號',
    'billing_country' => '帳單地址之國家',
    'shipping_address1' => '送貨地址之街道',
    'shipping_address2' => '送貨地址之大樓/套房',
    'shipping_city' => '送貨地址之城市',
    'shipping_state' => '送貨地址之州/省',
    'shipping_postal_code' => '送貨地址之郵遞區號',
    'shipping_country' => '送貨地址之國家',
    'classify' => '分類',
    'show_shipping_address_help' => '需要使用者提供其送貨地址',
    'ship_to_billing_address' => '寄送至帳單地址',
    'delivery_note' => '寄送註記',
    'show_tasks_in_portal' => '在用戶門戶頁面顯示任務',
    'cancel_schedule' => '取消排程',
    'scheduled_report' => '排程報告',
    'scheduled_report_help' => '以電子郵件按照 :format 寄送 :report 報告給 :email',
    'created_scheduled_report' => '報告排程成功',
    'deleted_scheduled_report' => '取消排程報告成功',
    'scheduled_report_attached' => '您已排程的 :type 報告已經附加其中。',
    'scheduled_report_error' => '排程報告建立失敗',
    'invalid_one_time_password' => '無效的一次性密碼',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => '接受 Apple Pay 與 Pay with Google',
    'requires_subdomain' => '此種付款類型需要一個 :link。',
    'subdomain_is_set' => '子網域已設定',
    'verification_file' => '驗證檔案',
    'verification_file_missing' => '接受付款需有驗證檔案。',
    'apple_pay_domain' => '使用<code>:domain</code> 作為 :link 的網域。',
    'apple_pay_not_supported' => '抱歉，您的瀏覽器不支援 Apple/Google Pay',
    'optional_payment_methods' => '可選擇的付款方式',
    'add_subscription' => '加入訂閱',
    'target_url' => '目標',
    'target_url_help' => '一旦所選擇的事件發生，此程式即將此項傳送至目標網址。',
    'event' => '事件',
    'subscription_event_1' => '已建立用戶',
    'subscription_event_2' => '已建立發票',
    'subscription_event_3' => '已建立報價單',
    'subscription_event_4' => '已建立付款資料',
    'subscription_event_5' => '已建立供應商',
    'subscription_event_6' => '已更新報價單',
    'subscription_event_7' => '已刪除報價單',
    'subscription_event_8' => '已更新發票',
    'subscription_event_9' => '已刪除發票',
    'subscription_event_10' => '已更新用戶',
    'subscription_event_11' => '已刪除用戶',
    'subscription_event_12' => '已刪除付款',
    'subscription_event_13' => '已更新供應商',
    'subscription_event_14' => '已刪除供應商',
    'subscription_event_15' => '已建立支出項目',
    'subscription_event_16' => '已更新支出項目',
    'subscription_event_17' => '已刪除支出項目',
    'subscription_event_18' => '已建立工作項目',
    'subscription_event_19' => '已更新工作項目',
    'subscription_event_20' => '已刪除任務',
    'subscription_event_21' => '已同意報價單',
    'subscriptions' => '訂閱',
    'updated_subscription' => '更新訂閱成功',
    'created_subscription' => '建立訂閱成功',
    'edit_subscription' => '編輯訂閱資料',
    'archive_subscription' => '歸檔訂閱資料',
    'archived_subscription' => '歸檔訂閱資料成功',
    'project_error_multiple_clients' => '專案不能屬於不同的用戶',
    'invoice_project' => '發票專案',
    'module_recurring_invoice' => '週期性發票',
    'module_credit' => '貸款',
    'module_quote' => '報價單與提案',
    'module_task' => '任務與專案',
    'module_expense' => '支出 & 供應商',
    'module_ticket' => '票證',
    'reminders' => '提醒通知',
    'send_client_reminders' => '以電子郵件寄送提醒通知',
    'can_view_tasks' => '任務顯示於入口頁面',
    'is_not_sent_reminders' => '提醒通知未寄送',
    'promotion_footer' => '您的優惠即將到期，立即以 :link 進行升級。',
    'unable_to_delete_primary' => '注意: 欲刪除這項公司資料，先刪除所有相連結的公司。',
    'please_register' => '請註冊您的帳號',
    'processing_request' => '正在處理要求',
    'mcrypt_warning' => '警告: Mcrypt 已失效，請執行 :command 以更新您的加密程序。',
    'edit_times' => '編輯時間',
    'inclusive_taxes_help' => '<b>在成本中包括稅金</b>',
    'inclusive_taxes_notice' => '一旦發票建立，此項設定無法被更改。',
    'inclusive_taxes_warning' => '警告: 現存的發票需要被再次存檔',
    'copy_shipping' => '複製送貨地址',
    'copy_billing' => '複製帳單地址',
    'quote_has_expired' => '報價單已過期，請聯絡該商家。',
    'empty_table_footer' => '顯示 0 項資料的 0 到 0項',
    'do_not_trust' => '不要記住這個裝置',
    'trust_for_30_days' => '信任 30 天',
    'trust_forever' => '永遠信任',
    'kanban' => '看板',
    'backlog' => '待辦清單',
    'ready_to_do' => '已準備就緒',
    'in_progress' => '處理中',
    'add_status' => '加入狀態',
    'archive_status' => '歸檔狀態',
    'new_status' => '新的狀態',
    'convert_products' => '轉換產品',
    'convert_products_help' => '自動將產品價格轉換為用戶的貨幣',
    'improve_client_portal_link' => '設定子域名以縮短用戶門戶頁面連結。',
    'budgeted_hours' => '列入預算的小時',
    'progress' => '進度',
    'view_project' => '檢視專案',
    'summary' => '摘要',
    'endless_reminder' => '不終止的提醒函',
    'signature_on_invoice_help' => '加入以下代碼，以在 PDF 上顯示用戶的簽名。',
    'signature_on_pdf' => '在 PDF 檔案上顯示',
    'signature_on_pdf_help' => '在發票/報價單 PDF 顯示用戶簽名。',
    'expired_white_label' => '白牌授權已過期',
    'return_to_login' => '回到登入頁面',
    'convert_products_tip' => '注意: 加入名為「:name」的 :link 以查看匯率。',
    'amount_greater_than_balance' => '此金額大於發票餘額，一筆貸款將與剩餘金額一起建立。',
    'custom_fields_tip' => '使用 <code>Label|Option1,Option2</code> 以顯示選取方塊。',
    'client_information' => '用戶資訊',
    'updated_client_details' => '更新用戶詳細資料成功',
    'auto' => '自動',
    'tax_amount' => '稅金金額',
    'tax_paid' => '已付稅',
    'none' => '無',
    'proposal_message_button' => '若要檢視您的 :amount 之提案，按一下以下按鈕。',
    'proposal' => '提案',
    'proposals' => '提案',
    'list_proposals' => '列出所有的提案',
    'new_proposal' => '新增提案',
    'edit_proposal' => '編輯提案',
    'archive_proposal' => '歸檔提案',
    'delete_proposal' => '刪除提案',
    'created_proposal' => '已成功建立提案',
    'updated_proposal' => '已成功更新提案',
    'archived_proposal' => '歸檔提案資料成功',
    'deleted_proposal' => '歸檔提案資料成功',
    'archived_proposals' => '歸檔 :count 份提案成功',
    'deleted_proposals' => '歸檔 :count 份提案成功',
    'restored_proposal' => '復原提案成功',
    'restore_proposal' => '復原提案',
    'snippet' => '程式碼片段',
    'snippets' => '程式碼片段',
    'proposal_snippet' => '程式碼片段',
    'proposal_snippets' => '程式碼片段',
    'new_proposal_snippet' => '新的程式碼片段',
    'edit_proposal_snippet' => '編輯程式碼片段',
    'archive_proposal_snippet' => '歸檔程式碼片段',
    'delete_proposal_snippet' => '刪除程式碼片段',
    'created_proposal_snippet' => '已成功建立程式碼片段',
    'updated_proposal_snippet' => '更新程式碼片段成功',
    'archived_proposal_snippet' => '歸檔程式碼片段成功',
    'deleted_proposal_snippet' => '歸檔程式碼片段成功',
    'archived_proposal_snippets' => '歸檔 :count 個程式碼片段成功',
    'deleted_proposal_snippets' => '歸檔 :count 個程式碼片段成功',
    'restored_proposal_snippet' => '復原程式碼片段成功',
    'restore_proposal_snippet' => '復原程式碼片段',
    'template' => '範本',
    'templates' => '範本',
    'proposal_template' => '範本',
    'proposal_templates' => '範本',
    'new_proposal_template' => '新範本',
    'edit_proposal_template' => '編輯範本',
    'archive_proposal_template' => '歸檔範本',
    'delete_proposal_template' => '刪除範本',
    'created_proposal_template' => '範本建立成功',
    'updated_proposal_template' => '更新範本成功',
    'archived_proposal_template' => '歸檔範本成功',
    'deleted_proposal_template' => '歸檔範本成功',
    'archived_proposal_templates' => '歸檔 :count 個範本成功',
    'deleted_proposal_templates' => '歸檔 :count 個範本成功',
    'restored_proposal_template' => '復原範本成功',
    'restore_proposal_template' => '復原範本',
    'proposal_category' => '類別',
    'proposal_categories' => '類別',
    'new_proposal_category' => '新類別',
    'edit_proposal_category' => '編輯類別',
    'archive_proposal_category' => '歸檔類別',
    'delete_proposal_category' => '刪除類別',
    'created_proposal_category' => '成功地建立類別',
    'updated_proposal_category' => '更新類別成功',
    'archived_proposal_category' => '歸檔類別成功',
    'deleted_proposal_category' => '歸檔類別成功',
    'archived_proposal_categories' => '歸檔 :count 項類別成功',
    'deleted_proposal_categories' => '歸檔 :count 項類別成功',
    'restored_proposal_category' => '復原類別成功',
    'restore_proposal_category' => '復原類別',
    'delete_status' => '刪除狀態',
    'standard' => '標準',
    'icon' => '圖示',
    'proposal_not_found' => '無法提供查詢的提案',
    'create_proposal_category' => '建立類別',
    'clone_proposal_template' => '再製範本',
    'proposal_email' => '提案的電子郵件',
    'proposal_subject' => ':account 的新提案 :number',
    'proposal_message' => '若要檢視您的 :amount 之提案，按一下以下連結。',
    'emailed_proposal' => '以電子郵件寄出提案成功',
    'load_template' => '載入範本',
    'no_assets' => '無圖片，拖曳檔案至此上傳',
    'add_image' => '新增圖片',
    'select_image' => '選擇圖片',
    'upgrade_to_upload_images' => '升級到企業版，以上傳圖片',
    'delete_image' => '刪除圖片',
    'delete_image_help' => '警告: 刪除這個圖片，將會在所有的提案中移除它。',
    'amount_variable_help' => '注意: 若經設定，發票的 $amount 欄位將使用 部分/存款 欄位；否則，它將使用發票餘額。',
    'taxes_are_included_help' => '注意: 內含稅已啟用。',
    'taxes_are_not_included_help' => '注意: 內含稅未啟用。',
    'change_requires_purge' => '需要 :link 帳號資料來變更這個設定。',
    'purging' => 'purging',
    'warning_local_refund' => '退款將會在程式中紀錄，但不會在由付款閘道處理。',
    'email_address_changed' => '電子郵件地址已改變',
    'email_address_changed_message' => '您的帳號所使用的電子郵件已從 :old_email 變更為 :new_email。',
    'test' => '測試',
    'beta' => 'Beta',
    'gmp_required' => '需要外掛程式 GMP 以匯出至 ZIP 檔案',
    'email_history' => '電子郵件歷程記錄',
    'loading' => '載入中',
    'no_messages_found' => '未找到訊息',
    'processing' => '處理中',
    'reactivate' => '重新生效',
    'reactivated_email' => '這個電子郵件地址已重新生效',
    'emails' => '電子郵件',
    'opened' => '已開啟',
    'bounced' => '已退回',
    'total_sent' => '總共已寄出',
    'total_opened' => '總共已開啟',
    'total_bounced' => '總共已退回',
    'total_spam' => '所有的垃圾郵件',
    'platforms' => '平台',
    'email_clients' => '電子郵件用戶端',
    'mobile' => '行動裝置',
    'desktop' => '電腦桌面',
    'webmail' => '網頁郵件',
    'group' => '群組',
    'subgroup' => '次群組',
    'unset' => '取消設定',
    'received_new_payment' => '您已收到一筆新的付款!',
    'slack_webhook_help' => '使用 :link 以接收付款通知。',
    'slack_incoming_webhooks' => '回應連入的 webhooks',
    'accept' => '接受',
    'accepted_terms' => '成功地接受最新的服務條款',
    'invalid_url' => '無效的 URL',
    'workflow_settings' => '工作流程設定',
    'auto_email_invoice' => '自動電子郵件',
    'auto_email_invoice_help' => '週期性發票建立後，自動以電子郵件寄出。',
    'auto_archive_invoice' => '自動歸檔',
    'auto_archive_invoice_help' => '發票已付款後，自動將它們歸檔。',
    'auto_archive_quote' => '自動歸檔',
    'auto_archive_quote_help' => '報價單轉換後，自動將它們歸檔。',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => '允許核准過期的報價單',
    'allow_approve_expired_quote_help' => '允許用戶核准過期的報價單。',
    'invoice_workflow' => '發票工作流程',
    'quote_workflow' => '報價單工作流程',
    'client_must_be_active' => '錯誤: 用戶必須處於使用中',
    'purge_client' => '清除用戶',
    'purged_client' => '清除用戶成功',
    'purge_client_warning' => '所有相關的紀錄 (發票、任務、支出、文件等等) 也將會刪除。',
    'clone_product' => '再製產品資料',
    'item_details' => '項目詳細資料',
    'send_item_details_help' => '將單項產品的詳細資料傳送到付款主頁面。',
    'view_proposal' => '檢視提案',
    'view_in_portal' => '在入口頁面檢視',
    'cookie_message' => '本網站使用 cookies 以確保您能在此得到最佳的使用經驗。',
    'got_it' => '瞭解了!',
    'vendor_will_create' => '將建立供應商',
    'vendors_will_create' => '將建立供應商',
    'created_vendors' => '建立 :count 筆供應商成功',
    'import_vendors' => '匯入供應商',
    'company' => '公司',
    'client_field' => '用戶欄位',
    'contact_field' => '聯絡人欄位',
    'product_field' => '產品欄位',
    'task_field' => '任務欄位',
    'project_field' => '專案欄位',
    'expense_field' => '支出欄位',
    'vendor_field' => '供應商欄位',
    'company_field' => '公司欄位',
    'invoice_field' => '發票欄位',
    'invoice_surcharge' => '發票額外費用',
    'custom_task_fields_help' => '建立工作時新增欄位。',
    'custom_project_fields_help' => '建立專案時新增欄位。',
    'custom_expense_fields_help' => '建立支出紀錄時新增欄位。',
    'custom_vendor_fields_help' => '建立供應商時新增欄位。',
    'messages' => '訊息',
    'unpaid_invoice' => '未付款之發票',
    'paid_invoice' => '已付款之發票',
    'unapproved_quote' => '未同意之報價單',
    'unapproved_proposal' => '未同意之提案',
    'autofills_city_state' => '自動填入的城市/國家',
    'no_match_found' => '未找到符合的資料',
    'password_strength' => '密碼強度',
    'strength_weak' => '弱',
    'strength_good' => '好',
    'strength_strong' => '強',
    'mark' => '品牌',
    'updated_task_status' => '更新工作狀態成功',
    'background_image' => '背景圖片',
    'background_image_help' => '使用 :link 來管理您的圖片，我們建議使用較小的檔案。',
    'proposal_editor' => '提案編輯器',
    'background' => '背景',
    'guide' => '指南',
    'gateway_fee_item' => '閘道費用項目',
    'gateway_fee_description' => '閘道的額外費用',
    'gateway_fee_discount_description' => '閘道費用折扣',
    'show_payments' => '顯示付款資料',
    'show_aging' => '顯示帳齡',
    'reference' => '參照',
    'amount_paid' => '已付金額',
    'send_notifications_for' => '寄送通知給',
    'all_invoices' => '所有發票',
    'my_invoices' => '我的發票',
    'payment_reference' => '付款參考',
    'maximum' => '最大',
    'sort' => '排序',
    'refresh_complete' => '重新整理完成',
    'please_enter_your_email' => '請輸入您的電子郵件',
    'please_enter_your_password' => '請輸入您的密碼',
    'please_enter_your_url' => '請輸入您的網址',
    'please_enter_a_product_key' => '請輸入產品金鑰',
    'an_error_occurred' => '發生錯誤',
    'overview' => '總覽',
    'copied_to_clipboard' => '複製 :value 到剪貼簿',
    'error' => '錯誤',
    'could_not_launch' => '無法啟動',
    'additional' => '額外',
    'ok' => '正常',
    'email_is_invalid' => '電子郵件無效',
    'items' => '個項目',
    'partial_deposit' => '存款',
    'add_item' => '加入項目',
    'total_amount' => '總金額',
    'pdf' => 'PDF',
    'invoice_status_id' => '發票狀態',
    'click_plus_to_add_item' => '按一下 + 來加入項目',
    'count_selected' => ':count 項已選取',
    'dismiss' => '撤銷',
    'please_select_a_date' => '請選取日期',
    'please_select_a_client' => '請選取一個用戶',
    'language' => '語言',
    'updated_at' => '更新',
    'please_enter_an_invoice_number' => '請輸入發票編號',
    'please_enter_a_quote_number' => '請輸入報價單編號',
    'clients_invoices' => ':client 的發票',
    'viewed' => '已檢視',
    'approved' => '已核准',
    'invoice_status_1' => '草稿',
    'invoice_status_2' => '已傳送',
    'invoice_status_3' => '已檢視',
    'invoice_status_4' => '已核准',
    'invoice_status_5' => '入口頁面',
    'invoice_status_6' => '已付款',
    'marked_invoice_as_sent' => '標記發票為已傳送成功',
    'please_enter_a_client_or_contact_name' => '請輸入用戶或連絡人姓名',
    'restart_app_to_apply_change' => '重新啟動應用程式以套用變更',
    'refresh_data' => '重新整理資料',
    'blank_contact' => '空白連絡人',
    'no_records_found' => '找不到記錄',
    'industry' => '工業',
    'size' => '大小',
    'net' => '淨額',
    'show_tasks' => '顯示任務',
    'email_reminders' => '電子郵件提醒',
    'reminder1' => '首次提醒',
    'reminder2' => '第二次提醒',
    'reminder3' => '第三次提醒',
    'send' => '傳送',
    'auto_billing' => '自動計費',
    'button' => '按鈕',
    'more' => '更多',
    'edit_recurring_invoice' => '編輯週期性發票',
    'edit_recurring_quote' => '編輯週期性報價單',
    'quote_status' => '報價單狀態',
    'please_select_an_invoice' => '請選取發票',
    'filtered_by' => '篩選依據',
    'payment_status' => '付款狀態',
    'payment_status_1' => '擱置',
    'payment_status_2' => '作廢',
    'payment_status_3' => '失敗',
    'payment_status_4' => '完成',
    'payment_status_5' => '部分退款',
    'payment_status_6' => '退款',
    'send_receipt_to_client' => '將收據傳送到用戶',
    'refunded' => '退款',
    'marked_quote_as_sent' => '標記報價單為已傳送成功',
    'custom_module_settings' => '自訂模組設定',
    'ticket' => '票證',
    'tickets' => '票證',
    'ticket_number' => '票證 #',
    'new_ticket' => '新票證',
    'edit_ticket' => '編輯票證',
    'view_ticket' => '檢視票證',
    'archive_ticket' => '歸檔票證',
    'restore_ticket' => '復原票證',
    'delete_ticket' => '刪除票證',
    'archived_ticket' => '歸檔票證成功',
    'archived_tickets' => '歸檔票證成功',
    'restored_ticket' => '復原票證成功',
    'deleted_ticket' => '刪除票證成功',
    'open' => '開啟',
    'new' => '新增',
    'closed' => '已關閉',
    'reopened' => '重新開啟',
    'priority' => '優先順序',
    'last_updated' => '上次更新時間',
    'comment' => '評論',
    'tags' => '標籤',
    'linked_objects' => '連結的物件',
    'low' => '低',
    'medium' => '中',
    'high' => '高',
    'no_due_date' => '未設定到期日期',
    'assigned_to' => '分配給',
    'reply' => '回覆',
    'awaiting_reply' => '等待回覆',
    'ticket_close' => '關閉票證',
    'ticket_reopen' => '重開票證',
    'ticket_open' => '開啟票證',
    'ticket_split' => '拆分票證',
    'ticket_merge' => '合併票證',
    'ticket_update' => '更新票證',
    'ticket_settings' => '票證設定',
    'updated_ticket' => '票證更新',
    'mark_spam' => '標記為垃圾郵件',
    'local_part' => '本地部份',
    'local_part_unavailable' => '取得的名稱',
    'local_part_available' => '可用的名稱',
    'local_part_invalid' => '名稱無效 (僅限字母數位，無空格)',
    'local_part_help' => '自訂入站支援電子郵件的本地部分, 即。YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => '寄件者的姓名是顯示的可識別寄件者, 而不是電子郵件地址 (即支援中心)',
    'local_part_placeholder' => '您的姓名',
    'from_name_placeholder' => '支援中心',
    'attachments' => '附件',
    'client_upload' => '用戶上傳',
    'enable_client_upload_help' => '允許用戶上載文件/附件',
    'max_file_size_help' => '最大檔案大小 (KB) 受您的文章 _ max _ size 和上載 _ max _ 檔案大小變數的限制, 如 PHP.INI 中設定的那樣',
    'max_file_size' => '最大檔案大小',
    'mime_types' => 'Mime 類型',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => '逗號分隔的允許的 mime 類型清單, 為所有',
    'ticket_number_start_help' => '票證號必須大於目前票證號',
    'new_ticket_template_id' => '新票證',
    'new_ticket_autoresponder_help' => '選擇範本將在建立新票證時向用戶/連絡人傳送自動回應',
    'update_ticket_template_id' => '更新後的票證',
    'update_ticket_autoresponder_help' => '選擇範本將在更新票證時向用戶/連絡人傳送自動回應',
    'close_ticket_template_id' => '已關閉票證',
    'close_ticket_autoresponder_help' => '選擇範本將在票證關閉時向用戶/連絡人傳送自動回應',
    'default_priority' => '預設優先順序',
    'alert_new_comment_id' => '新評論',
    'alert_comment_ticket_help' => '選取範本將在做出評論時 (向代理) 傳送通知。',
    'alert_comment_ticket_email_help' => '逗號分隔的電子郵件給 bcc 關於新的評論。',
    'new_ticket_notification_list' => '其它新票證通知',
    'update_ticket_notification_list' => '其它新評論通知',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => '票證分配',
    'alert_ticket_assign_agent_id_hel' => '選取範本將在分配票證時 (向代理) 傳送通知。',
    'alert_ticket_assign_agent_id_notifications' => '分配的其它票證通知',
    'alert_ticket_assign_agent_id_help' => '逗號分隔的電子郵件給 bcc 的票證分配。',
    'alert_ticket_transfer_email_help' => '逗號分隔的電子郵件給 bcc 的票證轉讓。',
    'alert_ticket_overdue_agent_id' => '過期票證',
    'alert_ticket_overdue_email' => '其它逾期票證通知',
    'alert_ticket_overdue_email_help' => '逗號分隔的電子郵件給 bcc 的票證期。',
    'alert_ticket_overdue_agent_id_help' => '選取範本將在票證過期時 (向代理) 傳送通知。',
    'ticket_master' => '票證主人',
    'ticket_master_help' => '有分配和傳送票證的能力。 將所有票證分配為給預設代理。',
    'default_agent' => '預設代理',
    'default_agent_help' => '如果選取，將自動分配給所有入站票證',
    'show_agent_details' => '顯示回應的代理詳細資訊',
    'avatar' => '頭像',
    'remove_avatar' => '刪除頭像',
    'ticket_not_found' => '找不到票證',
    'add_template' => '加入範本',
    'ticket_template' => '票證範本',
    'ticket_templates' => '票證範本',
    'updated_ticket_template' => '已更新票證範本',
    'created_ticket_template' => '已建立票證範本',
    'archive_ticket_template' => '歸檔範本',
    'restore_ticket_template' => '復原範本',
    'archived_ticket_template' => '歸檔範本成功',
    'restored_ticket_template' => '復原範本成功',
    'close_reason' => '讓我們知道您為何要關閉這張票證',
    'reopen_reason' => '讓我們知道您為何要重新開啟這張票證',
    'enter_ticket_message' => '請輸入訊息以更新票證',
    'show_hide_all' => '顯示/全部隱藏',
    'subject_required' => '需要主旨',
    'mobile_refresh_warning' => '若您使用行動 APP，您可能需要做一次重新整理。',
    'enable_proposals_for_background' => '上傳一個背景圖片 :link 以啟用提案模組。',
    'ticket_assignment' => '票證 :ticket_number 已分配給 :agent',
    'ticket_contact_reply' => '用戶 :contact 已更新票證 :ticket_number',
    'ticket_new_template_subject' => '票證 :ticket_number 已建立。',
    'ticket_updated_template_subject' => '票證 :ticket_number 已更新。',
    'ticket_closed_template_subject' => '票證 :ticket_number 已關閉。',
    'ticket_overdue_template_subject' => '票證 :ticket_number 現在過期',
    'merge' => '合併',
    'merged' => '合併',
    'agent' => '代理',
    'parent_ticket' => '上層票證',
    'linked_tickets' => '連結的票證',
    'merge_prompt' => '輸入要合併到的票證號',
    'merge_from_to' => '票證 #:old_ticket 合併到票證 #:new_ticket',
    'merge_closed_ticket_text' => '票證 #:old_ticket 已關閉和合併成票證 #:new_ticket - :subject',
    'merge_updated_ticket_text' => '票證 #:old_ticket 已關閉和合併到這張票證中',
    'merge_placeholder' => '合併票證 #:ticket 到以下票證',
    'select_ticket' => '選取票證',
    'new_internal_ticket' => '新的內部票證',
    'internal_ticket' => '內部票證',
    'create_ticket' => '建立票證',
    'allow_inbound_email_tickets_external' => '透過電子郵件的新票證 (用戶)',
    'allow_inbound_email_tickets_external_help' => '允許用戶以電子郵件建立票證',
    'include_in_filter' => '包含在篩選器',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => '比較',
    'hosted_login' => '託管登入',
    'selfhost_login' => 'Selfhost 登入',
    'google_login' => 'Google 登入',
    'thanks_for_patience' => '感謝您的耐心，而我們努力實現這些功能。\n\n希望在接下來的幾個月裡完成它們。\n\n直到那時我們將繼續支援',
    'legacy_mobile_app' => '舊版行動 App',
    'today' => '今天',
    'current' => '目前',
    'previous' => '以前',
    'current_period' => '目前期限',
    'comparison_period' => '比較期限',
    'previous_period' => '上一期限',
    'previous_year' => '上一年度',
    'compare_to' => '比較',
    'last_week' => '上個星期',
    'clone_to_invoice' => '再製到發票',
    'clone_to_quote' => '再製到報價單',
    'convert' => '轉換',
    'last7_days' => '最近 7 天',
    'last30_days' => '最近 30 天',
    'custom_js' => '自訂 JS',
    'adjust_fee_percent_help' => '調整百分比以計入費用',
    'show_product_notes' => '顯示產品詳細資訊',
    'show_product_notes_help' => '在產品下拉清單<b>包含描述和成本</b>',
    'important' => '重要',
    'thank_you_for_using_our_app' => '感謝您使用我們的應用程式!',
    'if_you_like_it' => '如果您喜歡，請',
    'to_rate_it' => '給它評分。',
    'average' => '平均',
    'unapproved' => '未同意',
    'authenticate_to_change_setting' => '請進行身份驗證以變更這個設定',
    'locked' => '鎖定',
    'authenticate' => '身份驗證',
    'please_authenticate' => '請驗證',
    'biometric_authentication' => '生物識別驗證',
    'auto_start_tasks' => '自動啟動任務',
    'budgeted' => '預算',
    'please_enter_a_name' => '請輸入姓名',
    'click_plus_to_add_time' => '按一下 + 來加入項目',
    'design' => '設計',
    'password_is_too_short' => '密碼太短',
    'failed_to_find_record' => '找不到記錄',
    'valid_until_days' => '有效至',
    'valid_until_days_help' => '在未來許多天，自動將報價的 <b>有效截止日</b> 值設定在這個日期。 留白以停用。',
    'usually_pays_in_days' => '日',
    'requires_an_enterprise_plan' => '需要企業方案',
    'take_picture' => '拍照',
    'upload_file' => '上傳檔案',
    'new_document' => '新新文件',
    'edit_document' => '編輯文件',
    'uploaded_document' => '已成功上載文件',
    'updated_document' => '已成功更新文件',
    'archived_document' => '已成功封存文件',
    'deleted_document' => '已成功刪除文件',
    'restored_document' => '已成功還原文件',
    'no_history' => '無歷史記錄',
    'expense_status_1' => '已登入',
    'expense_status_2' => '擱置',
    'expense_status_3' => '已開立發票的',
    'no_record_selected' => '未選取任何記錄',
    'error_unsaved_changes' => '請儲存或取消您的變更',
    'thank_you_for_your_purchase' => '感謝您的購買!',
    'redeem' => '兌換',
    'back' => '返回',
    'past_purchases' => '過去購買',
    'annual_subscription' => '年度訂閱',
    'pro_plan' => '專業方案',
    'enterprise_plan' => '企業方案',
    'count_users' => ':count users',
    'upgrade' => '升級',
    'please_enter_a_first_name' => '請輸入名字',
    'please_enter_a_last_name' => '請輸入姓氏',
    'please_agree_to_terms_and_privacy' => '請同意服務條款和隱私政策以建立帳戶。',
    'i_agree_to_the' => '我同意',
    'terms_of_service_link' => '服務條款',
    'privacy_policy_link' => '隱私政策',
    'view_website' => '檢視網站',
    'create_account' => '建立帳戶',
    'email_login' => '電子郵件登入',
    'late_fees' => '滯納金',
    'payment_number' => '付款號碼',
    'before_due_date' => '到期日之前',
    'after_due_date' => '到期日之後',
    'after_invoice_date' => '發票日之後',
    'filtered_by_user' => '依使用者篩選',
    'created_user' => '已成功建立使用者',
    'primary_font' => '主要字型',
    'secondary_font' => '次要字型',
    'number_padding' => '數字填充',
    'general' => '一般',
    'surcharge_field' => '附加費欄位',
    'company_value' => '公司值',
    'credit_field' => '信用欄位',
    'payment_field' => '付款欄位',
    'group_field' => '群組欄位',
    'number_counter' => '數字計數器',
    'number_pattern' => '數字模式',
    'custom_javascript' => '自訂 JavaScript',
    'portal_mode' => '入口網站模式',
    'attach_pdf' => '附加 PDF 檔案',
    'attach_documents' => '附加文件',
    'attach_ubl' => '附加 UBL',
    'email_style' => '電子郵件樣式',
    'processed' => '處理',
    'fee_amount' => '費用金額',
    'fee_percent' => '費用百分比',
    'fee_cap' => '費用上限',
    'limits_and_fees' => '限額/費用',
    'credentials' => '認證',
    'require_billing_address_help' => '需要使用者提供其帳單地址',
    'require_shipping_address_help' => '需要使用者提供其送貨地址',
    'deleted_tax_rate' => '成功刪除稅率',
    'restored_tax_rate' => '成功恢復稅率',
    'provider' => '供應商',
    'company_gateway' => '付款閘道',
    'company_gateways' => '付款閘道',
    'new_company_gateway' => '新增閘道',
    'edit_company_gateway' => '編輯閘道',
    'created_company_gateway' => '建立閘道資料成功',
    'updated_company_gateway' => '更新閘道資料成功',
    'archived_company_gateway' => '封存閘道資料成功',
    'deleted_company_gateway' => '刪除閘道資料成功',
    'restored_company_gateway' => '復原閘道成功',
    'continue_editing' => '繼續編輯',
    'default_value' => '預設值',
    'currency_format' => '貨幣格式',
    'first_day_of_the_week' => '每星期的第一天',
    'first_month_of_the_year' => '年度的第一個月',
    'symbol' => '符號',
    'ocde' => '代碼',
    'date_format' => '日期格式',
    'datetime_format' => '日期時間格式',
    'send_reminders' => '傳送提醒',
    'timezone' => '時區',
    'filtered_by_group' => '依群組篩選',
    'filtered_by_invoice' => '依發票篩選',
    'filtered_by_client' => '依用戶端篩選',
    'filtered_by_vendor' => '依供應商篩選',
    'group_settings' => '群組設定',
    'groups' => '群組',
    'new_group' => '新增群組',
    'edit_group' => '編輯群組',
    'created_group' => '已成功建立群組',
    'updated_group' => '已成功更新群組',
    'archived_group' => '已成功封存群組',
    'deleted_group' => '已成功刪除群組',
    'restored_group' => '已成功還原群組',
    'upload_logo' => '上傳徽標',
    'uploaded_logo' => '已成功上傳徽標',
    'saved_settings' => '已成功儲存設定',
    'device_settings' => '裝置設定',
    'credit_cards_and_banks' => '信用卡 & 銀行',
    'price' => '價格',
    'email_sign_up' => '電子郵件註冊',
    'google_sign_up' => 'Google 註冊',
    'sign_up_with_google' => '使用 Google 註冊',
    'long_press_multiselect' => '長按多選',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
